'use strict';

var index = require('./index-DnF1G--N.js');
var EventBus = require('./EventBus-Dq4GLNJp.js');

var ToastEventsEnum;
(function (ToastEventsEnum) {
    ToastEventsEnum["OPEN_NOTIFICATIONS_FEED"] = "OPEN_NOTIFICATIONS_FEED";
    ToastEventsEnum["CLOSE_TOAST"] = "CLOSE_TOAST";
    // Event to update the transaction toast data
    ToastEventsEnum["TRANSACTION_TOAST_DATA_UPDATE"] = "TRANSACTION_TOAST_DATA_UPDATE";
    // Event to update the custom toast data
    ToastEventsEnum["CUSTOM_TOAST_DATA_UPDATE"] = "CUSTOM_TOAST_DATA_UPDATE";
})(ToastEventsEnum || (ToastEventsEnum = {}));

const toastListCss = ":root{--mx-accent:#FFFFFF;--mx-white:#FFFFFF;--mx-black:#000000;--mx-neutral-900:#171717;--mx-neutral-50:#FAFAFA;--mx-neutral-400:#A3A3A3;--mx-text:var(--mx-white);--mx-primary-text:#262626;--mx-secondary-text:#868686;--mx-warning-text:#facc15;--mx-body-label-color:#a09a93;--mx-warning-text:#facc15;--mx-tx-bg:rgba(53, 53, 53);--mx-tx-bg-transparent:rgba(53, 53, 53, 0.3);--mx-tx-text-primary:#e8e8e8;--mx-tx-text-secondary:#737373;--mx-toast-backdrop-blur:38px;--mx-toast-success-bg:#1D6030;--mx-toast-success-color:#4ADE80;--mx-toast-pending-bg:#453412;--mx-toast-pending-color:#FACC15;--mx-toast-error-bg:rgba(255, 71, 71, 0.2);--mx-toast-error-color:#FF4747;--font-family-roobert:\"Roobert PRO\", system-ui, -apple-system, sans-serif;--mx-explorer-link-color:var(--mx-text-primary);--mx-transition:0.3s ease-in-out}.toast-list{position:fixed;bottom:16px;right:16px;z-index:9999;display:flex;flex-direction:column;gap:8px;max-width:100%;pointer-events:none}.toast-list-bottom{bottom:64px}.toast-list>*{pointer-events:auto}.view-all-button-container{position:absolute;bottom:-48px;right:0;z-index:1}.view-all-button{border-radius:100px;border:0.5px solid var(--mx-tx-bg);background:var(--mx-tx-bg);backdrop-filter:blur(38px);padding:8px 16px;color:var(--mx-tx-text-primary);font-family:var(--font-family-roobert);font-size:16px;font-style:normal;font-weight:400;line-height:140%;cursor:pointer;transition:opacity 0.2s ease}.view-all-button:hover{opacity:0.9}";

const ToastList = class {
    constructor(hostRef) {
        index.registerInstance(this, hostRef);
        this.eventBus = new EventBus.EventBus();
    }
    async getEventBus() {
        return this.eventBus;
    }
    disconnectedCallback() {
        this.eventBus.unsubscribe(ToastEventsEnum.TRANSACTION_TOAST_DATA_UPDATE, this.transactionToastUpdate.bind(this));
        this.eventBus.unsubscribe(ToastEventsEnum.CUSTOM_TOAST_DATA_UPDATE, this.customToastsUpdate.bind(this));
    }
    handleCustomToastDelete(toastId) {
        this.eventBus.publish(ToastEventsEnum.CLOSE_TOAST, toastId);
    }
    handleTransactionToastDelete(toastId) {
        this.eventBus.publish(ToastEventsEnum.CLOSE_TOAST, toastId);
    }
    handleViewAllClick() {
        this.eventBus.publish(ToastEventsEnum.OPEN_NOTIFICATIONS_FEED);
    }
    render() {
        var _a, _b, _c;
        const hasTransactionToasts = ((_a = this.transactionToasts) === null || _a === void 0 ? void 0 : _a.length) > 0;
        return (index.h("div", { key: '681fedfc5f336ffaedb942adb896352b57197fcc', class: {
                'toast-list': true,
                'toast-list-bottom': hasTransactionToasts,
            }, id: "toast-list" }, (_b = this.customToasts) === null || _b === void 0 ? void 0 :
            _b.map(toast => index.h("mvx-generic-toast", { toast: toast, onDeleteToast: this.handleCustomToastDelete.bind(this, toast.toastId) })), (_c = this.transactionToasts) === null || _c === void 0 ? void 0 :
            _c.map(toast => (index.h("mvx-transaction-toast", Object.assign({}, toast, { onDeleteToast: this.handleTransactionToastDelete.bind(this, toast.toastId) })))), hasTransactionToasts && (index.h("div", { key: '16fa9b3e4109a89fb80060179aa2cc3ba612e695', class: "view-all-button-container" }, index.h("button", { key: '09a0b4891472ed64dd7d63fbbffdf626e636cb74', class: "view-all-button", onClick: this.handleViewAllClick.bind(this) }, "View All")))));
    }
    transactionToastUpdate(payload) {
        this.transactionToasts = [...payload];
        index.forceUpdate(this);
    }
    customToastsUpdate(payload) {
        this.customToasts = [...payload];
        index.forceUpdate(this);
    }
    componentDidLoad() {
        this.eventBus.subscribe(ToastEventsEnum.TRANSACTION_TOAST_DATA_UPDATE, this.transactionToastUpdate.bind(this));
        this.eventBus.subscribe(ToastEventsEnum.CUSTOM_TOAST_DATA_UPDATE, this.customToastsUpdate.bind(this));
    }
};
ToastList.style = toastListCss;

exports.mvx_toast_list = ToastList;
//# sourceMappingURL=mvx-toast-list.entry.cjs.js.map

//# sourceMappingURL=mvx-toast-list.cjs.entry.js.map