import { r as registerInstance, h } from './index-D3R9UMmk.js';
import { c as faCheck, d as faCopy, e as faChevronDown, f as faTimes, g as faHourglass } from './index-V-nc4w6z.js';
import { D as DataTestIdsEnum } from './dataTestIds.enum-uM8_L1mr.js';
import { g as getIconHtmlFromIconDefinition } from './getIconHtmlFromIconDefinition-qtCpOx4f.js';

const isWindowAvailable = () => typeof window != 'undefined' && typeof (window === null || window === void 0 ? void 0 : window.location) != 'undefined';

function fallbackCopyTextToClipboard(text) {
    let success = false;
    if (!document || !document.body) {
        console.error('Document or document.body is not available');
        return success;
    }
    const textArea = document.createElement('textarea');
    textArea.value = text;
    textArea.style.position = 'fixed';
    textArea.style.left = '-9999px';
    textArea.style.top = '0';
    document.body.appendChild(textArea);
    try {
        textArea.focus();
        textArea.setSelectionRange(0, textArea.value.length);
        success = document.execCommand('copy');
    }
    catch (err) {
        console.error('Fallback: Oops, unable to copy', err);
    }
    finally {
        document.body.removeChild(textArea);
    }
    return success;
}
async function copyToClipboard(text) {
    if (!isWindowAvailable()) {
        return false;
    }
    let success = false;
    if (!navigator.clipboard) {
        success = fallbackCopyTextToClipboard(text);
    }
    else {
        success = await navigator.clipboard.writeText(text).then(function done() {
            return true;
        }, function error(err) {
            console.error('Async: Could not copy text: ', err);
            return false;
        });
    }
    return success;
}

const copyButtonCss = ".copy-button{color:#6c757d}";

const CopyButton = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
        this.class = 'copy-button';
        this.iconClass = 'copy-button-icon';
        this.isSuccess = false;
        this.handleClick = async (event) => {
            event.preventDefault();
            event.stopPropagation();
            const trimmedText = this.text ? this.text.trim() : this.text;
            const success = await copyToClipboard(trimmedText);
            this.isSuccess = success;
            if (success) {
                this.timeoutId = window.setTimeout(() => {
                    this.isSuccess = false;
                }, 1000);
            }
        };
    }
    disconnectedCallback() {
        // Clear the timeout if the component is unmounted
        if (this.timeoutId) {
            clearTimeout(this.timeoutId);
            this.timeoutId = undefined; // Reset the timeout ID
        }
    }
    render() {
        var _a, _b;
        const copyIcon = (_a = this.copyIcon) !== null && _a !== void 0 ? _a : faCopy;
        const successIcon = (_b = this.successIcon) !== null && _b !== void 0 ? _b : faCheck;
        return (h("a", { key: '24db0c49002be78e6eff6cbd14ff53b4a0a866a7', href: "/#", class: this.class, onClick: this.handleClick }, h("mvx-fa-icon", { key: '06625249df645dadafdf18e1607911e38d6e43a8', icon: this.isSuccess ? successIcon : copyIcon, class: this.iconClass })));
    }
};
CopyButton.style = copyButtonCss;

const DefaultTransactionIconSmall = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
    }
    render() {
        return (h("svg", { key: '6e1d96c86f380d3b15455432211f91d332b51c21', xmlns: "http://www.w3.org/2000/svg", width: "16", height: "16", viewBox: "0 0 16 17", fill: "none" }, h("g", { key: 'd75968c27ae40fff2e78e8a0e453b7bbdca11f7a', "clip-path": "url(#clip0_8136_19149)" }, h("rect", { key: '158f87982a63c00c40fc70cc9d2f1bf517839779', y: "0.319824", width: "16", height: "16", rx: "8", fill: "#3B3D48" }), h("path", { key: '9204cc8fc978d662ed5cde74f2be937d040b6c3d', d: "M4 5.75732C4 4.97607 4.64062 4.31982 5.4375 4.31982C6.21875 4.31982 6.875 4.97607 6.875 5.75732V6.44482H9.125V5.75732C9.125 4.97607 9.76562 4.31982 10.5625 4.31982C11.3438 4.31982 12 4.97607 12 5.75732V5.81982C12 6.64795 11.3281 7.31982 10.5 7.31982H9.875V9.31982H10.5C11.3281 9.31982 12 9.9917 12 10.8198V10.8823C12 11.6792 11.3438 12.3198 10.5625 12.3198C9.76562 12.3198 9.125 11.6792 9.125 10.8823V10.1948H6.875V10.8823C6.875 11.6792 6.21875 12.3198 5.4375 12.3198C4.64062 12.3198 4 11.6792 4 10.8823V10.8198C4 9.9917 4.67188 9.31982 5.5 9.31982H6.125V7.31982H5.5C4.67188 7.31982 4 6.64795 4 5.81982V5.75732ZM6.125 6.56982V5.75732C6.125 5.38232 5.8125 5.06982 5.4375 5.06982C5.04688 5.06982 4.75 5.38232 4.75 5.75732V5.81982C4.75 6.2417 5.07812 6.56982 5.5 6.56982H6.125ZM6.875 9.44482H9.125V7.19482H6.875V9.44482ZM6.125 10.0698H5.5C5.07812 10.0698 4.75 10.4136 4.75 10.8198V10.8823C4.75 11.2729 5.04688 11.5698 5.4375 11.5698C5.8125 11.5698 6.125 11.2729 6.125 10.8823V10.0698ZM9.875 10.8823C9.875 11.2729 10.1719 11.5698 10.5625 11.5698C10.9375 11.5698 11.25 11.2729 11.25 10.8823V10.8198C11.25 10.4136 10.9062 10.0698 10.5 10.0698H9.875V10.8823ZM9.875 6.56982H10.5C10.9062 6.56982 11.25 6.2417 11.25 5.81982V5.75732C11.25 5.38232 10.9375 5.06982 10.5625 5.06982C10.1719 5.06982 9.875 5.38232 9.875 5.75732V6.56982Z", fill: "#EEEEF1" })), h("defs", { key: 'a149d766f7ebb39591ca384f8391e849448965c2' }, h("clipPath", { key: '08805c12e155ddc9bbb02995f81608a3b85d060c', id: "clip0_8136_19149" }, h("rect", { key: 'd008e6ce4df8bf7e0859297425c697d59d7891c0', y: "0.319824", width: "16", height: "16", rx: "8", fill: "white" })))));
    }
};

const transactionToastDetailsCss = ".transaction-details-container {\n  display: flex;\n  flex-direction: column;\n  align-items: flex-start;\n  align-self: stretch;\n  width: 100%;\n}\n\n.transaction-details-status {\n  display: flex;\n  align-items: center;\n  gap: 12px;\n  align-self: stretch;\n  margin-bottom: 12px;\n  cursor: pointer;\n}\n\n.transaction-details-status-icon {\n  color: var(--mx-tx-text-primary);\n  transition: transform var(--mx-transition);\n  align-items: center;\n  display: flex;\n  height: 20px;\n  width: 20px;\n  justify-content: center;\n\n  .svg-inline--fa {\n    height: 14px;\n    width: 14px;\n    color: var(--mx-tx-text-primary);\n  }\n}\n\n.transaction-details-status-icon.rotate-up {\n  transform: rotate(90deg);\n}\n\n.transaction-details-status-text {\n  color: var(--mx-tx-text-primary);\n  font-family: var(--font-family-roobert);\n  font-size: 16px;\n  font-style: normal;\n  font-weight: 400;\n  line-height: 140%; /* 19.6px */\n}\n\n.transaction-details-list {\n  display: flex;\n  flex-direction: column;\n  align-items: flex-start;\n  gap: 4px;\n  align-self: stretch;\n  max-height: 0;\n  overflow: hidden;\n  transition: max-height var(--mx-transition);\n}\n\n.transaction-details-list.expanded {\n  max-height: 500px;\n}\n\n.view-all-container {\n  width: 100%;\n  display: flex;\n  justify-content: center;\n  margin-top: 8px;\n}\n\n.show-more-button {\n  background: none;\n  border: none;\n  color: var(--mx-tx-text-primary);\n  font-family: var(--font-family-roobert);\n  font-size: 12px;\n  font-weight: 500;\n  cursor: pointer;\n  padding: 4px 8px;\n  border-radius: 4px;\n  transition: background-color var(--mx-transition);\n}\n\n.show-more-button:hover {\n  background-color: rgba(0, 0, 0, 0.05);\n}";

const TransactionToastDetails = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
        this.maxShownTransactions = 5;
        this.isExpanded = false;
        this.showAllTransactions = false;
    }
    toggleExpand() {
        this.isExpanded = !this.isExpanded;
        // Reset showAllTransactions when collapsing
        if (!this.isExpanded) {
            this.showAllTransactions = false;
        }
    }
    showMoreTransactions() {
        this.showAllTransactions = true;
    }
    render() {
        if (this.transactions == null) {
            return null;
        }
        const hasMoreTransactionsToShow = this.transactions.length > this.maxShownTransactions;
        const hiddenTransactionsCount = this.transactions.length - this.maxShownTransactions;
        const visibleTransactions = this.showAllTransactions ? this.transactions : this.transactions.slice(0, this.maxShownTransactions);
        return (h("div", { class: "transaction-details-container" }, h("div", { class: "transaction-details-status", onClick: this.toggleExpand.bind(this) }, h("mvx-fa-icon", { icon: faChevronDown, class: `transaction-details-status-icon ${this.isExpanded ? 'rotate-up' : ''}` }), h("span", { class: "transaction-details-status-text" }, this.processedTransactionsStatus)), h("div", { class: {
                'transaction-details-list': true,
                'expanded': this.isExpanded,
            } }, visibleTransactions.map(({ hash, status, link }, index) => (h("mvx-transaction-toast-details-body", { transactionClass: this.transactionClass, hash: hash, status: status, link: link, index: `#${index + 1}`, key: hash }))), hasMoreTransactionsToShow && !this.showAllTransactions && (h("div", { class: "view-all-container" }, h("button", { type: "button", class: "show-more-button", onClick: this.showMoreTransactions.bind(this) }, "Show ", hiddenTransactionsCount, " more"))))));
    }
};
TransactionToastDetails.style = transactionToastDetailsCss;

const transactionToastDetailsBodyCss = ".transaction-details-list-item{display:flex;align-items:center;gap:12px;align-self:stretch}.transaction-details-list-item-icon{width:24px;height:24px;border-radius:50%;display:flex;align-items:center;justify-content:center}.transaction-details-list-item-icon svg,.transaction-details-list-item-icon .svg-inline--fa{width:12px;height:12px}.transaction-details-list-item-icon-success{background-color:#2B6C39}.transaction-details-list-item-icon-success svg,.transaction-details-list-item-icon-success .svg-inline--fa{color:#6AD788}.transaction-details-list-item-icon-pending{background-color:#453412}.transaction-details-list-item-icon-pending svg,.transaction-details-list-item-icon-pending .svg-inline--fa{color:#FACC15}.transaction-details-list-item-icon-fail{background-color:var(--mx-toast-error-bg)}.transaction-details-list-item-icon-fail svg,.transaction-details-list-item-icon-fail .svg-inline--fa{color:var(--mx-toast-error-icon)}.transaction-details-list-item-hash-index{color:var(--mx-tx-text-secondary);font-family:var(--font-family-roobert);font-size:12px;font-style:normal;font-weight:400}.transaction-details-list-item-hash-value{color:var(--mx-tx-text-secondary);font-family:var(--font-family-roobert);font-size:12px;font-style:normal;font-weight:400;max-width:220px;width:100%}.transaction-details-list-item-copy-button-icon .svg-inline--fa{color:var(--mx-tx-text-primary);width:12px;height:12px}.transaction-details-list-item-explorer-link-icon .svg-inline--fa{color:var(--mx-tx-text-secondary);width:12px;height:12px}";

const iconData = {
    pending: faHourglass,
    success: faCheck,
    fail: faTimes,
    invalid: faTimes,
};
const TransactionDetailsBody = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
        this.transactionClass = 'transaction-details-list-item';
    }
    render() {
        const statusIcon = this.status ? iconData[this.status] : null;
        const iconHtml = statusIcon ? getIconHtmlFromIconDefinition(statusIcon) : null;
        return (h("div", { class: this.transactionClass, key: this.hash, "data-testid": DataTestIdsEnum.transactionDetailsToastBody }, iconHtml && (h("div", { key: 'e18daed8eb2ae919cefdb42feeafbb90aabce6c2', innerHTML: iconHtml, class: {
                'transaction-details-list-item-icon': true,
                'transaction-details-list-item-icon-success': this.status === 'success',
                'transaction-details-list-item-icon-pending': this.status === 'pending',
                'transaction-details-list-item-icon-fail': ['fail', 'invalid'].includes(this.status),
            } })), h("div", { key: '1e3c8f53053e79ca33c8ec5469ffb399a1755306', class: "transaction-details-list-item-hash-index" }, this.index), h("div", { key: 'a88fd21f1a88c859a748ff0ee8cce5c6b87de722', class: "transaction-details-list-item-hash-value" }, h("mvx-trim-text", { key: '0b10be033ab81765329618e9b8bc1c8dd9c335d0', text: this.hash })), h("mvx-explorer-link", { key: 'e78938533c1d3d9196f122e27167b3f9f0efd129', iconClass: "transaction-details-list-item-explorer-link-icon", link: this.link }), h("mvx-copy-button", { key: 'c2af13986f41865d793f2ea40326e4abd4d6ced3', iconClass: "transaction-details-list-item-copy-button-icon", text: this.hash })));
    }
};
TransactionDetailsBody.style = transactionToastDetailsBodyCss;

export { CopyButton as mvx_copy_button, DefaultTransactionIconSmall as mvx_default_transaction_icon_small, TransactionToastDetails as mvx_transaction_toast_details, TransactionDetailsBody as mvx_transaction_toast_details_body };
//# sourceMappingURL=mvx-copy-button.mvx-default-transaction-icon-small.mvx-transaction-toast-details.mvx-transaction-toast-details-body.entry.js.map

//# sourceMappingURL=mvx-copy-button_4.entry.js.map