import { r as registerInstance, h, g as getElement } from './index-D3R9UMmk.js';
import { b as faArrowUpRightFromSquare } from './index-V-nc4w6z.js';
import { c as classNames } from './index-CcLhQtEp.js';
import { D as DataTestIdsEnum } from './dataTestIds.enum-uM8_L1mr.js';
import './_commonjsHelpers-Dj2_voLF.js';

const explorerLinkCss = ".explorer-link{text-decoration:none;color:var(--mx-explorer-link-color, -webkit-link);}";

const ExplorerLink = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
        this.class = 'explorer-link';
        this.iconClass = 'explorer-link-icon';
        this.hasSlotContent = false;
    }
    componentWillLoad() {
        this.hasSlotContent = !!this.hostElement.querySelector('[slot="content"]');
    }
    render() {
        var _a, _b;
        return (h("a", { key: '88b13ed31963a66055c3daaa45e0b962a9221974', "data-testid": this.dataTestId, href: this.link, target: "_blank", class: this.class, rel: "noreferrer" }, this.hasSlotContent ? h("slot", { name: "content" }) : (_a = this.text) !== null && _a !== void 0 ? _a : h("mvx-fa-icon", { icon: (_b = this.icon) !== null && _b !== void 0 ? _b : faArrowUpRightFromSquare, class: this.iconClass })));
    }
    get hostElement() { return getElement(this); }
};
ExplorerLink.style = explorerLinkCss;

const ELLIPSIS = '...';

const trimTextCss = ".trim {\n  display: flex;\n  max-width: 100%;\n  overflow: hidden;\n  position: relative;\n  white-space: nowrap;\n\n  &.overflow {\n    .ellipsis {\n      display: block;\n    }\n  }\n\n  .left {\n    flex-shrink: 1;\n    font-size: 1px;\n\n    overflow: hidden;\n    text-overflow: ellipsis;\n    text-align: left;\n  }\n\n  .right {\n    flex-shrink: 1;\n    font-size: 1px;\n\n    overflow: hidden;\n    text-overflow: ellipsis;\n    white-space: nowrap;\n    direction: rtl;\n    text-align: right;\n  }\n\n  .left span,\n  .right span {\n    font-size: 0.875rem;\n    pointer-events: none;\n    user-select: none;\n  }\n\n  .ellipsis {\n    flex-shrink: 0;\n    pointer-events: none;\n    user-select: none;\n  }\n\n  /* IE fix */\n  @media all and (-ms-high-contrast: none), (-ms-high-contrast: active) {\n    .right {\n      text-overflow: clip;\n    }\n  }\n\n  /* SAFARI fix */\n  @supports (-webkit-hyphens: none) {\n    .right,\n    .left {\n      letter-spacing: -0.001em;\n    }\n    .right {\n      text-overflow: clip;\n    }\n  }\n\n  .hidden-text-ref {\n    position: absolute;\n    display: block;\n    color: transparent;\n  }\n\n  @media (max-width: 1199.98px) {\n    max-width: 26rem;\n  }\n\n  @media (max-width: 991.98px) {\n    max-width: 12rem;\n  }\n\n  @media (max-width: 768px) {\n    max-width: 8rem;\n  }\n}\n\n.trim-wrapper {\n  display: flex;\n  max-width: 100%;\n  overflow: hidden;\n}\n\na:hover > .trim span {\n  color: #007bff;\n\n  &.hidden-text-ref {\n    color: transparent;\n  }\n}\n\na > .trim span,\n.text-primary > .trim span {\n  color: #1b46c2;\n\n  &.hidden-text-ref {\n    color: transparent;\n  }\n}\n\n.table .trim {\n  max-width: 10rem;\n}\n\n.table .trim-only-sm .trim {\n  max-width: none;\n\n  @media (max-width: 768px) {\n    max-width: 13rem;\n  }\n}\n\n.trim-fs-sm .trim {\n  .left span,\n  .right span,\n  .ellipsis {\n    font-size: 0.875rem;\n  }\n}\n\n.table .trim-size-xl .trim {\n  @media (max-width: 768px) {\n    max-width: 13rem;\n  }\n}\n";

const TrimText = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
        this.overflow = false;
        this.checkOverflow = () => {
            if (this.hiddenTextRef && this.trimRef) {
                const hiddenWidth = this.hiddenTextRef.offsetWidth;
                const containerWidth = this.trimRef.offsetWidth;
                // Batch state updates to minimize re-renders
                if (this.overflow !== hiddenWidth > containerWidth) {
                    this.overflow = hiddenWidth > containerWidth;
                }
            }
        };
    }
    componentDidLoad() {
        this.setupResizeObserver();
        // Initial check after DOM elements exist
        requestAnimationFrame(() => this.checkOverflow());
    }
    disconnectedCallback() {
        var _a;
        (_a = this.resizeObserver) === null || _a === void 0 ? void 0 : _a.disconnect();
    }
    setupResizeObserver() {
        this.resizeObserver = new ResizeObserver(() => {
            this.checkOverflow();
        });
        if (this.trimRef) {
            this.resizeObserver.observe(this.trimRef);
        }
    }
    render() {
        var _a;
        const trimmedText = this.getTrimmedText();
        return (h("span", { key: '91c7b8afc625c249aa7245c964b72f0e83352f2f', ref: el => (this.trimRef = el), class: classNames('trim', this.class, { overflow: this.overflow }), "data-testid": (_a = this.dataTestId) !== null && _a !== void 0 ? _a : DataTestIdsEnum.trim }, h("span", { key: 'ace8fb9b362ea08183cc3d86584fc2822e3257de', ref: el => (this.hiddenTextRef = el), class: "hidden-text-ref" }, this.text), this.overflow ? (h("div", { class: "trim-wrapper" }, h("span", { class: "left" }, h("span", null, trimmedText.left)), h("span", { class: "ellipsis" }, ELLIPSIS), h("span", { class: "right" }, h("span", null, trimmedText.right)))) : (h("span", null, this.text))));
    }
    getTrimmedText() {
        const middleIndex = Math.floor(this.text.length / 2);
        return {
            left: this.text.slice(0, middleIndex),
            right: this.text.slice(middleIndex),
        };
    }
    get el() { return getElement(this); }
};
TrimText.style = trimTextCss;

export { ExplorerLink as mvx_explorer_link, TrimText as mvx_trim_text };
//# sourceMappingURL=mvx-explorer-link.mvx-trim-text.entry.js.map

//# sourceMappingURL=mvx-explorer-link_2.entry.js.map