import { h, r as registerInstance, c as createEvent, F as Fragment } from './index-D3R9UMmk.js';
import { D as DataTestIdsEnum } from './dataTestIds.enum-uM8_L1mr.js';

function trimAddress(s) {
    const firstFour = s.slice(0, 6);
    const lastFour = s.slice(-6);
    return `${firstFour}...${lastFour}`;
}
const renderAccounts = ({ shownAccounts = [], onSelectAccount, selectedIndex }) => {
    return (h("div", { class: "account-list", "data-testid": DataTestIdsEnum.addressTableContainer },
        h("div", { class: "account-header" },
            h("div", { class: "account-header-item" }, "Address"),
            h("div", { class: "account-header-item" }, "Balance"),
            h("div", { class: "account-header-item" }, "#")),
        shownAccounts.map(account => (h("div", { class: "account-row", onClick: () => onSelectAccount(account.index) },
            h("div", { class: "address-row-item-data " },
                h("input", { type: "radio", name: "account", checked: account.index === selectedIndex, value: account.index }),
                h("span", { class: "address" }, trimAddress(account.address))),
            h("div", { class: "address-row-item-data" }, account.balance),
            h("div", { class: "address-row-item-data" }, account.index))))));
};

const ledgerAccountScreenScss = ".account-header{display:flex;align-items:center;background-color:#ced4da;line-height:1;padding:16px;text-align:left;font-size:14px;border-radius:8px;padding-right:20px}.account-header-item{flex:1}.account-header-item:first-child{width:55%;max-width:55%}.account-header-item:last-child{width:32px;max-width:32px;flex-basis:32px;text-align:center}.account-list{width:100%;min-height:300px;max-height:300px;position:relative;overflow:auto}.account-row{display:flex;align-items:center;padding:16px;border-radius:8px;cursor:pointer}.account-row:hover{background-color:#f5f5f5}.address-row-item-data{font-size:14px;line-height:1;flex:1;text-align:left;display:flex;align-items:center;padding-right:16px}.address-row-item-data:last-child{width:32px;max-width:32px;flex-basis:32px;text-align:center;justify-content:center;padding-right:0}.navigation{display:flex;justify-content:center;gap:10rem;margin-top:20px}.navigation-button{background:transparent;border:none;cursor:pointer}.navigation-button:hover{color:#1a56db}.navigation-button:disabled{color:#737373;pointer-events:none}.access-button{display:block;width:200px;margin:20px auto;padding:12px;background-color:#1a56db;color:white;border:none;border-radius:8px;cursor:pointer}.access-button:disabled{background-color:#a1a1a1;color:#e0e0e0;cursor:not-allowed;opacity:0.6;box-shadow:none;transform:none}";

const LedgerAccountScreen = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
        this.selectAccount = createEvent(this, "selectAccount");
        this.nextPage = createEvent(this, "nextPage");
        this.prevPage = createEvent(this, "prevPage");
        this.accessWallet = createEvent(this, "accessWallet");
    }
    render() {
        const isSelectedIndexOnPage = this.accountScreenData.accounts.some(({ index }) => index === this.selectedIndex);
        const accountsList = this.accountScreenData.isLoading || this.accountScreenData.accounts.length === 0 ? (h("mvx-generic-spinner", { "data-testid": DataTestIdsEnum.ledgerLoading })) : (renderAccounts({
            shownAccounts: this.accountScreenData.accounts,
            onSelectAccount: (index) => this.selectAccount.emit(index),
            selectedIndex: this.selectedIndex,
        }));
        return (h(Fragment, { key: 'b0ec8c215b0f4dede098b71c6051ba3c8c8fdeb0' }, accountsList, !this.accountScreenData.isLoading && this.accountScreenData.accounts.length !== 0 && (h(Fragment, { key: '84bed13ab30037ac68fd1d600dcbbc27338e7a18' }, h("div", { key: '084ceab80f731d6e02d632f26ae5db25efd0f011', class: "navigation" }, h("button", { key: 'feef8b25f45694005b3d653a38f68eefe48bdedd', onClick: () => this.prevPage.emit(), disabled: this.accountScreenData.startIndex <= 0, "data-testid": DataTestIdsEnum.prevBtn, class: "navigation-button" }, '< ', " Prev"), h("button", { key: 'b5fe944de4a207cda7c0e56d1947798089fa82b7', onClick: () => this.nextPage.emit(), "data-testid": DataTestIdsEnum.nextBtn, class: "navigation-button" }, "Next", ' >')), h("button", { key: '977d31454dfdaa77688888b539a014c5c44ed33d', "data-testid": DataTestIdsEnum.confirmBtn, class: "access-button", onClick: () => this.accessWallet.emit(), disabled: !isSelectedIndexOnPage }, "Access Wallet")))));
    }
};
LedgerAccountScreen.style = ledgerAccountScreenScss;

const ledgerConfirmScreenScss = ".address-section{line-height:1.5;margin-top:40px;font-size:16px;text-align:center}.address-section .address-description{color:#858688}.address-section .address-data{background-color:#ced4da;line-height:1;padding:12px;text-align:center;border-radius:8px;word-break:break-word}.address-section .address-header{background-color:#ced4da;line-height:1;padding:12px;text-align:center;border-radius:8px}.address-footer{font-size:14px;color:var(--gray-700);line-height:1.5;position:relative;margin-top:40px;padding-top:40px}.address-footer::before{height:1px;content:'';left:0;bottom:100%;right:0;position:absolute;background-color:var(--gray-700)}.address-footer a{color:var(--primary)}";

const LedgerConnectConfirmBody = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
    }
    render() {
        var _a, _b, _c;
        return (h("div", { key: '0266faaf48fe2a5bae8160759e9a552e09270826', "data-testid": DataTestIdsEnum.ledgerConfirmAddress, class: "address-section" }, h("div", { key: 'ca350d951b6f66feeb1483ee1f19b0551fb6d957', class: "address-section" }, h("div", { key: '17a5488cded164041dc7b0616c351e09d15798c5', class: "address-description" }, this.confirmScreenData.confirmAddressText), h("div", { key: '8cd3b3f771b98b978e56ebea91d0543afc2e9861', class: "address-header" }, this.confirmScreenData.selectedAddress)), h("div", { key: 'c27aa0193c6402a2fb82fa2bad52d4cd1d55b542', class: "address-section" }, h("div", { key: 'e6cacab59eaf0c790dc8336629a895cc1662cf9d', class: "address-description" }, (_a = this.confirmScreenData) === null || _a === void 0 ? void 0 : _a.authText), h("div", { key: '3aeb7451ecb02d6b8ba01d7d3de244ce9b078150', class: "address-data" }, (_b = this.confirmScreenData) === null || _b === void 0 ? void 0 : _b.data), h("div", { key: 'bc877743680e38344e4d2b30dceeb77ed7e1b31b', class: "address-description" }, (_c = this.confirmScreenData) === null || _c === void 0 ? void 0 : _c.areShownText)), h("div", { key: '4454fcd00d02de923ca1b5f62fcdb490e056ec91', class: "address-footer" }, h("div", { key: '369e585dae7572d4f3bee4a95137d6472b2e34ff' }, "Select Approve on your device to confirm."), h("div", { key: '6aec059bd95e69c586c79a2224e6939d871a705d' }, "Or, if it does not match, close this page and", ' ', h("a", { key: '992e75ed7831f530493318ff69240956274077f1', href: "https://help.multiversx.com/en/", target: "_blank", rel: "noreferrer" }, "contact support"), "."))));
    }
};
LedgerConnectConfirmBody.style = ledgerConfirmScreenScss;

const ledgerConnectScreenScss = ".access-button{display:block;width:200px;margin:20px auto;padding:12px;background-color:#1a56db;color:white;border:none;border-radius:8px;cursor:pointer}.access-button:disabled{background-color:#a1a1a1;color:#e0e0e0;cursor:not-allowed;opacity:0.6;box-shadow:none;transform:none}.connection-link{display:flex;justify-content:center}";

const LedgerConnectScreen = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
        this.connect = createEvent(this, "connect");
    }
    render() {
        var _a, _b, _c, _d;
        return (h("div", { key: 'b4d85dd649d2637fb1b258972adbcb84d096529d' }, ((_a = this.connectScreenData) === null || _a === void 0 ? void 0 : _a.error) && h("p", { key: '194280a98b6e7bc393d1ff5ff21e81ea4e73c9f2' }, this.connectScreenData.error), ((_b = this.connectScreenData) === null || _b === void 0 ? void 0 : _b.customContentMarkup) && ((_c = this.connectScreenData) === null || _c === void 0 ? void 0 : _c.customContentMarkup), h("button", { key: '095d6fc3c56b72a9febb429d5a0d31d48f3d7b82', "data-testid": DataTestIdsEnum.ledgerConnectBtn, class: "access-button", onClick: () => this.connect.emit(), disabled: (_d = this.connectScreenData) === null || _d === void 0 ? void 0 : _d.disabled }, "Connect Ledger"), h("a", { key: 'a0e39be16ae8cd5d97e00451a659a1635c4efbcb', href: "https://support.ledger.com/hc/en-us/articles/115005165269-Connection-issues-with-Windows-or-Linux", target: "_blank", rel: "noopener noreferrer", class: "connection-link" }, "Having connection issues?")));
    }
};
LedgerConnectScreen.style = ledgerConnectScreenScss;

export { LedgerAccountScreen as mvx_ledger_account_screen, LedgerConnectConfirmBody as mvx_ledger_confirm_screen, LedgerConnectScreen as mvx_ledger_connect_screen };
//# sourceMappingURL=mvx-ledger-account-screen.mvx-ledger-confirm-screen.mvx-ledger-connect-screen.entry.js.map

//# sourceMappingURL=mvx-ledger-account-screen_3.entry.js.map