import { r as registerInstance, f as forceUpdate, h } from './index-D3R9UMmk.js';
import { D as DataTestIdsEnum } from './dataTestIds.enum-uM8_L1mr.js';
import { L as LedgerConnectBase, a as LedgerConnectEventsEnum } from './LedgerConnectBase-C_QIdNvO.js';
import './EventBus-S9juR7eS.js';

const ledgerConnectPanelCss = ".ledger-connect-content{height:100%;display:flex;flex-direction:column;padding:24px}.ledger-connect-header{margin-bottom:24px}.ledger-connect-header h2{font-size:24px;font-weight:500;margin:0 0 8px 0;color:#000}.ledger-connect-header h4{font-size:16px;font-weight:400;margin:0;color:#666}.ledger-connect-body{flex:1;overflow-y:auto}";

const LedgerConnectPanel = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
        this.data = {
            accountScreenData: null,
            confirmScreenData: null,
            connectScreenData: {},
        };
        this.isOpen = false;
        this.selectedIndex = 0;
    }
    componentWillLoad() {
        this.ledgerConnectBase = new LedgerConnectBase(this.data);
    }
    componentDidLoad() {
        this.ledgerConnectBase.subscribeEventBus(this.getEventBusSubscription());
        this.ledgerConnectBase.eventBus.subscribe(LedgerConnectEventsEnum.OPEN_LEDGER_CONNECT_PANEL, this.handleOpen.bind(this));
        this.ledgerConnectBase.eventBus.subscribe(LedgerConnectEventsEnum.CLOSE_LEDGER_CONNECT_PANEL, this.onClose.bind(this, { isUserClick: false }));
    }
    disconnectedCallback() {
        this.ledgerConnectBase.unsubscribeEventBus(this.getEventBusSubscription());
        this.ledgerConnectBase.eventBus.unsubscribe(LedgerConnectEventsEnum.OPEN_LEDGER_CONNECT_PANEL, this.handleOpen.bind(this));
        this.ledgerConnectBase.eventBus.unsubscribe(LedgerConnectEventsEnum.CLOSE_LEDGER_CONNECT_PANEL, this.onClose.bind(this, { isUserClick: false }));
    }
    handleConnect() {
        this.ledgerConnectBase.eventBus.publish(LedgerConnectEventsEnum.CONNECT_DEVICE);
    }
    handleOpen() {
        this.isOpen = true;
    }
    handleClose() {
        this.isOpen = false;
        this.onClose({ isUserClick: true });
    }
    onClose(props = { isUserClick: true }) {
        this.isOpen = false;
        if (props.isUserClick) {
            this.ledgerConnectBase.eventBus.publish(LedgerConnectEventsEnum.CLOSE_LEDGER_CONNECT_PANEL);
        }
    }
    accessWallet() {
        this.ledgerConnectBase.accessWallet();
    }
    selectAccount(index) {
        this.ledgerConnectBase.selectAccount(index);
        this.selectedIndex = this.ledgerConnectBase.selectedIndex;
    }
    async nextPage() {
        this.ledgerConnectBase.nextPage();
    }
    async prevPage() {
        this.ledgerConnectBase.prevPage();
    }
    async getEventBus() {
        return this.ledgerConnectBase.getEventBus();
    }
    getEventBusSubscription() {
        return {
            closeFn: () => this.onClose({ isUserClick: false }),
            forceUpdateFn: () => {
                this.data = this.ledgerConnectBase.data;
                forceUpdate(this);
            },
        };
    }
    getHeaderContent(accountScreenData, confirmScreenData) {
        if (accountScreenData) {
            return (h("div", { class: "ledger-connect-header" }, h("h2", { "data-testid": `${DataTestIdsEnum.addressTableContainer}Title` }, "Access your wallet"), h("h4", { "data-testid": `${DataTestIdsEnum.addressTableContainer}SubTitle` }, "Choose the wallet you want to access")));
        }
        if (confirmScreenData) {
            return (h("div", { class: "ledger-connect-header" }, h("h2", null, "Confirm"), h("h4", null, "Confirm Ledger Address")));
        }
        return (h("div", { class: "ledger-connect-header" }, h("h2", null, "Connect Ledger"), h("h4", null, "Unlock your device & open the MultiversX App")));
    }
    getBodyContent(accountScreenData, confirmScreenData, connectScreenData) {
        if (accountScreenData) {
            return (h("mvx-ledger-account-screen", { accountScreenData: accountScreenData, selectedIndex: this.selectedIndex, onSelectAccount: (event) => this.selectAccount(event.detail), onAccessWallet: () => this.accessWallet(), onPrevPage: () => this.prevPage(), onNextPage: () => this.nextPage() }));
        }
        if (confirmScreenData) {
            return h("mvx-ledger-confirm-screen", { confirmScreenData: confirmScreenData });
        }
        return h("mvx-ledger-connect-screen", { connectScreenData: connectScreenData, onConnect: this.handleConnect.bind(this) });
    }
    render() {
        const { accountScreenData, confirmScreenData, connectScreenData } = this.data;
        const bodyContent = this.getBodyContent(accountScreenData, confirmScreenData, connectScreenData);
        return (h("mvx-side-panel", { key: '35d688857b47ff7693df2f41a151569184ccd0c8', isOpen: this.isOpen, panelClassName: "ledger-connect-panel", onClose: this.handleClose.bind(this) }, h("div", { key: '1af25d0155b98064ea42928a55b995c9f92d294d', class: "ledger-connect-content" }, this.getHeaderContent(accountScreenData, confirmScreenData), h("div", { key: 'ce2e83b078c020e7bb2e40a84e6f701988b12ef1', class: "ledger-connect-body" }, bodyContent))));
    }
};
LedgerConnectPanel.style = ledgerConnectPanelCss;

export { LedgerConnectPanel as mvx_ledger_connect_panel };
//# sourceMappingURL=mvx-ledger-connect-panel.entry.js.map

//# sourceMappingURL=mvx-ledger-connect-panel.entry.js.map