import { r as registerInstance, h } from './index-D3R9UMmk.js';
import { D as DataTestIdsEnum } from './dataTestIds.enum-uM8_L1mr.js';
import { f as formatAddress } from './index-39TxyvVb.js';
import { s as state } from './signTransactionsPanelStore-CAFeDr7k.js';

const signTransactionComponentCss = "* {\n  margin: 0;\n  padding: 0;\n  box-sizing: border-box;\n}\n\n.transaction-container {\n  display: flex;\n  flex-direction: column;\n  padding: 0rem 1rem 0rem 1rem;\n  gap: 1rem;\n}\n\n.receiver-container {\n  display: flex;\n  flex-direction: column;\n  align-items: flex-start;\n  gap: 4px;\n  line-height: 1;\n}\n\n.data-container {\n  display: flex;\n  flex-direction: column;\n  align-items: flex-start;\n  gap: 4px;\n  line-height: 1;\n}\n\n.data-content-container {\n  display: block;\n  width: 100%;\n  min-height: 100px;\n  height: 100px;\n  border: 1px solid #ccc;\n  border-radius: 4px;\n  padding: 8px;\n  overflow-y: auto;\n  font-family: inherit;\n  font-size: inherit;\n  background-color: #f9f9f9;\n  white-space: pre-wrap;\n  word-wrap: break-word;\n  color: #333;\n}\n\n.data-content {\n  opacity: 0.6;\n}\n\n.fee-container {\n  display: flex;\n  flex-direction: column;\n  align-items: flex-start;\n  gap: 4px;\n  line-height: 1;\n}\n\n.sign-button-container {\n  display: flex;\n  flex-direction: column;\n}\n\n.sign-back-button {\n  display: inline-block;\n  padding: 8px 12px;\n  background-color: transparent;\n  color: #1a56db;\n  border: none;\n  border-radius: 4px;\n  cursor: pointer;\n  text-decoration: none;\n  font-size: 16px;\n\n  &:hover {\n    text-decoration: underline;\n    color: #0033a0;\n  }\n\n  &:active {\n    color: #001f70;\n  }\n\n  &:disabled {\n    color: #a1a1a1;\n    cursor: not-allowed;\n    text-decoration: none;\n    opacity: 0.6;\n  }\n}\n\n.sign-button {\n  display: block;\n  width: 200px;\n  margin: 0 auto;\n  padding: 12px;\n  background-color: #1a56db;\n  color: white;\n  border: none;\n  border-radius: 8px;\n  cursor: pointer;\n\n  &:disabled {\n    background-color: #a1a1a1;\n    color: #e0e0e0;\n    cursor: not-allowed;\n    opacity: 0.6;\n    box-shadow: none;\n    transform: none;\n  }\n}\n\n.highlight {\n  opacity: 1;\n}\n";

var __rest = (undefined && undefined.__rest) || function (s, e) {
    var t = {};
    for (var p in s)
        if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
            t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
const SignTransaction = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
    }
    getSignButtonProps() {
        const { needsSigning } = state.commonData;
        if (needsSigning) {
            return {
                'signText': 'Sign',
                'disabled': state.isWaitingForSignature,
                'data-testid': DataTestIdsEnum.signTransactionBtn,
                'onClick': state.onConfirm,
            };
        }
        return {
            'signText': 'Next',
            'disabled': false,
            'data-testid': DataTestIdsEnum.signNextTransactionBtn,
            'onClick': state.onConfirm,
        };
    }
    getBackButtonProps() {
        const { transactionsCount, currentIndex } = state.commonData;
        const isMultipleTransactions = transactionsCount > 1;
        if (!isMultipleTransactions) {
            return {};
        }
        if (currentIndex === 0) {
            return {
                'data-testid': DataTestIdsEnum.signCancelBtn,
                'backButtonText': 'Cancel',
                'onClick': state.onCancel,
            };
        }
        return {
            'data-testid': DataTestIdsEnum.signBackBtn,
            'backButtonText': 'Back',
            'onClick': state.onBack,
            'disabled': state.isWaitingForSignature,
        };
    }
    getHighlightedData() {
        const { data, highlight } = state.commonData;
        if (!highlight || !data) {
            return data;
        }
        const parts = data.split(highlight);
        return (h("span", null, parts.map((part, index) => (h("span", null, h("span", { class: "data-content" }, part), index < parts.length - 1 && h("span", { class: "highlight" }, highlight))))));
    }
    render() {
        const { receiver, scCall } = state.commonData;
        const _a = this.getSignButtonProps(), { signText } = _a, signButtonProps = __rest(_a, ["signText"]);
        const _b = this.getBackButtonProps(), { backButtonText } = _b, backButtonProps = __rest(_b, ["backButtonText"]);
        const highlightedData = this.getHighlightedData();
        return (h("div", { key: '0a1624c4494171725e7c790275ded0711475c48a', class: "transaction-container" }, this.header, h("div", { key: '6c007f6a9bcf9a9f794bb1d5afc7282d32f57d22', class: "receiver-container" }, h("p", { key: '07939c79bba48453d19b560cac2bc2660613234a' }, "To"), h("p", { key: '8264fd0565f6bbe226887990bcd794131abc9f84' }, formatAddress(receiver, 40))), h("mvx-transaction-fee-component", { key: '9b31561bee96d1ba0ac959b50fd9e0f171c08c58' }), scCall && (h("div", { key: 'e7699b5bad4b7b590d3382792c46d2e76a36923f', class: "data-container" }, h("p", { key: '61b71377a8acfa69d3e0fe578e6e34c16d0cce83' }, "Smart Contract Call"), h("div", { key: '5f6eda17fa42f0c45b0641b31bc2fe4eea6cdc34', class: "data-content-container" }, scCall))), h("div", { key: 'd4c0d74612b6a790f5c2bc0f3a1b8cf948a0b449', class: "data-container" }, h("p", { key: '7a43db58d1bf9aca66104eb99cf96e9a9bb2481e' }, "Data"), h("div", { key: '21d0a76ef527fb9b7f4d20d19fd81a3246bd43c4', class: "data-content-container" }, highlightedData)), h("div", { key: '43f582b8248cb7cbf349a2f044d74b488ed4ae69', class: "sign-button-container" }, h("button", Object.assign({ key: '92624f8b52a3b3fffba78a425354d75d47a703ce', class: "sign-button" }, signButtonProps), signText), backButtonText && (h("button", Object.assign({ key: '54665911aee4db0d6c59e7887167fc106981b4d8', class: "sign-back-button" }, backButtonProps), backButtonText)))));
    }
};
SignTransaction.style = signTransactionComponentCss;

const transactionFeeComponentCss = "*{margin:0;padding:0;box-sizing:border-box}.transaction-fee-container{display:flex;flex-direction:column;align-items:flex-start;gap:4px;line-height:1;padding:16px;border-radius:8px;background:var(--white)}.fee-header{display:flex;justify-content:space-between;align-items:center;margin-bottom:8px}.edit-button{background:none;border:none;cursor:pointer;padding:4px;color:var(--text-secondary)}.edit-button:hover{color:var(--text-primary)}.gas-options{margin-top:16px;padding-top:16px;border-top:1px solid var(--border-color);padding:1rem;background:#f8f9fa;border-radius:8px;width:100%}.top-section{display:flex;justify-content:space-between;align-items:center;margin-bottom:1rem}.gas-price-section .label,.gas-limit-section .label{color:#6c757d;font-size:0.875rem;margin-bottom:0.25rem}.gas-price-section .value,.gas-limit-section .value{display:flex;align-items:center;font-size:1rem;font-weight:500;color:#212529;margin:0}.gas-limit-section{padding-top:1rem;border-top:1px solid #dee2e6}.radio-group{display:inline-flex;border:1px solid #dee2e6;border-radius:4px;overflow:hidden;margin-left:12px}.radio-option{position:relative}.radio-option input[type=\"radio\"]{position:absolute;opacity:0;width:0;height:0}.radio-option input[type=\"radio\"]:checked+label{background:#0d6efd;color:white}.radio-option label{display:inline-block;padding:4px 8px;font-size:12px;cursor:pointer;border-right:1px solid #dee2e6;transition:all 0.2s ease}.radio-option label:hover{background:#e9ecef}.radio-option:last-child label{border-right:none}";

const TransactionFeeComponent = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
        this.showGasOptions = false;
        this.toggleGasOptions = () => {
            this.showGasOptions = !this.showGasOptions;
        };
        this.handlePpuChange = (value) => () => {
            state.onSetPpu(value);
        };
    }
    render() {
        const { egldLabel, feeInFiatLimit, feeLimit, gasLimit, gasPrice, ppu, isEditable, ppuOptions } = state.commonData;
        return (h("div", { key: '60c025ff26c214eed7420cad0052692713c94b34', class: "transaction-fee-container" }, h("div", { key: 'f3c6e5d7190b6fe0676dad4bc4919c46876bb34e', class: "fee-header" }, h("p", { key: 'f668ea32e085173281de4c844cc14abd447529f2' }, "Transaction fee"), isEditable && (h("button", { key: 'f7bfd5685b1df3be6fbec675cabdff9687b68dfc', onClick: this.toggleGasOptions, class: "edit-button" }, "Edit"))), feeLimit && (h("p", { key: '49bc48f863a3661d84ddb4b9fd4c4bf5bfadf0fa' }, h("span", { key: '30765612ce0dd7c46213b898dfdc526d783e7dad' }, feeLimit), "\u00A0", h("span", { key: '63a6a52e7c030608bcd793e7abd6a2cb91ce72e4' }, egldLabel))), h("p", { key: 'ce5095af4e734138dd72188f6cfa884181ef9a5b' }, "\u2248", feeInFiatLimit), this.showGasOptions && (h("div", { key: '6fc63b8b938ed941b88328e8ffc23fa94af2999a', class: "gas-options" }, h("div", { key: 'ca7c352c51fe18e9693c059a2691a5eb27e3273c', class: "top-section" }, h("div", { key: '70a6e75ea5fff6fff4fa36d07fc9f091e5cf5b0c', class: "gas-price-section" }, h("div", { key: '94a1c55011b3151febbd955ea05edbca8fe674a2', class: "label" }, "Gas Price"), h("div", { key: '1efb762c00188670a8813cf358a2a69a1a463eae', class: "value" }, gasPrice)), ppuOptions && ppuOptions.length > 0 && (h("div", { key: '0d9be568fadf454c62c8b9c4956725328e10e26a', class: "radio-group" }, ppuOptions.map(option => (h("div", { class: "radio-option" }, h("input", { disabled: !isEditable, type: "radio", id: `ppu${option.value}`, name: "ppu", value: option.value, checked: ppu === option.value, onChange: this.handlePpuChange(option.value) }), h("label", { htmlFor: `ppu${option.value}` }, option.label))))))), h("div", { key: '6cba2fd48d12ba03f384da1d090cfc2263253923', class: "gas-limit-section" }, h("div", { key: 'f119033027f3f4cfcde981ea13b9a24780a8e939', class: "label" }, "Gas Limit"), h("div", { key: 'ec2ab5e551e7df5ac986de85090b4c4277c0fcaa', class: "value" }, gasLimit))))));
    }
};
TransactionFeeComponent.style = transactionFeeComponentCss;

export { SignTransaction as mvx_sign_transaction_component, TransactionFeeComponent as mvx_transaction_fee_component };
//# sourceMappingURL=mvx-sign-transaction-component.mvx-transaction-fee-component.entry.js.map

//# sourceMappingURL=mvx-sign-transaction-component_2.entry.js.map