import { r as registerInstance, c as createEvent, h, F as Fragment } from './index-D3R9UMmk.js';
import { f as faTimes } from './index-V-nc4w6z.js';
import { D as DataTestIdsEnum } from './dataTestIds.enum-uM8_L1mr.js';
import { c as classNames } from './index-CcLhQtEp.js';
import './_commonjsHelpers-Dj2_voLF.js';

const transactionToastCss = ".transaction-toast{position:relative}";

const TransactionToast = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
        this.deleteToast = createEvent(this, "deleteToast");
        this.toastId = '';
        this.processedTransactionsStatus = '';
        this.transactions = [];
    }
    handleDeleteToast() {
        this.deleteToast.emit();
    }
    render() {
        var _a, _b;
        return (h("div", { key: '8821d03a3d9096168442edf9205e53f176e6bd5b', class: "transaction-toast" }, h("mvx-transaction-toast-progress", { key: this.toastId, startTime: (_a = this.transactionProgressState) === null || _a === void 0 ? void 0 : _a.startTime, endTime: (_b = this.transactionProgressState) === null || _b === void 0 ? void 0 : _b.endTime }, h("mvx-transaction-toast-content", { key: '4ff6380fe7a9cd5b19958c6da631c1538e802951', fullWidth: this.fullWidth, toastDataState: this.toastDataState, transactions: this.transactions, processedTransactionsStatus: this.processedTransactionsStatus, onDeleteToast: this.handleDeleteToast.bind(this) }))));
    }
};
TransactionToast.style = transactionToastCss;

const transactionToastContentCss = ".transaction-toast-content-wrapper {\n  position: relative;\n  display: flex;\n  max-width: 400px;\n  padding: 12px;\n  flex-direction: column;\n  align-items: flex-start;\n  gap: 4px;\n  border-radius: 12px;\n  border: 0.5px solid var(--mx-tx-bg);\n  background: var(--mx-tx-bg);\n  backdrop-filter: blur(38px);\n  color: var(--mx-tx-text-primary);\n\n  .svg-inline--fa {\n    color: var(--mx-tx-text-primary);\n  }\n}\n\n.transaction-toast-content-wrapper.full-width {\n  max-width: 100%;\n}\n\n.transaction-toast-content {\n  display: flex;\n  align-items: flex-start;\n  gap: 12px;\n  align-self: stretch;\n}\n\n.transaction-toast-icon {\n  border-radius: 50%;\n  width: 20px;\n  height: 20px;\n\n  svg, img, .svg-inline--fa {\n    width: 20px;\n    height: 20px;\n    border-radius: 50%;\n  }\n}\n\n.transaction-toast-details {\n  display: flex;\n  flex-direction: column;\n  align-items: flex-start;\n  gap: 4px;\n  flex: 1 0 0;\n}\n\n.transaction-toast-details-header {\n  display: flex;\n  align-items: center;\n  gap: 12px;\n  align-self: stretch;\n  justify-content: space-between;\n  padding: 0;\n  padding: 0;\n}\n\n.transaction-toast-title {\n  color: var(--mx-tx-text-primary);\n  font-family: var(--font-family-roobert);\n  font-size: 16px;\n  font-size: 16px;\n  font-style: normal;\n  font-weight: 700;\n  line-height: 140%;\n  white-space: nowrap;\n  overflow: hidden;\n  text-overflow: ellipsis;\n  margin: 0;\n  max-width: 220px;\n}\n\n.transaction-toast-title-short {\n  max-width: 160px;\n}\n\n.transaction-toast-content-wrapper.full-width .transaction-toast-title {\n  max-width: 100%;\n}\n\n\n.transaction-toast-amount {\n  color: var(--mx-tx-text-primary);\n  font-family: var(--font-family-roobert);\n  font-size: 16px;\n  font-size: 16px;\n  font-style: normal;\n  font-weight: 400;\n  letter-spacing: -0.14px;\n}\n\n.transaction-toast-details-info {\n  display: flex;\n  align-items: flex-start;\n  gap: 4px;\n  align-self: stretch;\n}\n\n.transaction-toast-details-info-text {\n  color: var(--mx-tx-text-secondary);\n  font-family: var(--font-family-roobert);\n  font-size: 16px;\n  font-size: 16px;\n  font-style: normal;\n  font-weight: 400;\n  line-height: 16px;\n  letter-spacing: -0.14px;\n  max-width: 160px;\n}\n\n.transaction-toast-details-info-icon {\n  border-radius: 50%;\n  width: 16px;\n  height: 16px;\n\n  img {\n    border-radius: 50%;\n    width: 16px;\n    height: 16px;\n  }\n}\n\n.transaction-toast-action-button {\n  color: var(--mx-tx-text-primary);\n  display: flex;\n  width: 14px;\n  height: 14px;\n  flex-direction: column;\n  justify-content: center;\n  flex-shrink: 0;\n\n  .svg-inline--fa {\n    color: var(--mx-tx-text-primary);\n    text-align: center;\n    height: 14px;\n  }\n}";

const TransactionToastContent = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
        this.deleteToast = createEvent(this, "deleteToast");
    }
    handleDeleteToast() {
        this.deleteToast.emit();
    }
    renderPrimaryIcon() {
        var _a, _b;
        const transaction = (_a = this.transactions) === null || _a === void 0 ? void 0 : _a[0];
        if (!(transaction === null || transaction === void 0 ? void 0 : transaction.asset)) {
            return h("mvx-default-transaction-icon-small", null);
        }
        if (transaction.asset.imageUrl) {
            return h("img", { src: transaction.asset.imageUrl, alt: "Transaction icon", class: "transaction-toast-icon", loading: "lazy" });
        }
        if (transaction.asset.icon) {
            return h("mvx-fa-icon", { icon: transaction.asset.icon, class: "transaction-toast-icon" });
        }
        if (transaction.asset.text) {
            return h("span", { class: "transaction-toast-icon" }, transaction.asset.text);
        }
        if (this.toastDataState.icon) {
            return h("fa-icon", { icon: this.toastDataState.icon, class: `transaction-toast-icon ${(_b = this.toastDataState.iconClassName) !== null && _b !== void 0 ? _b : ''}` });
        }
        return h("mvx-default-transaction-icon-small", null);
    }
    renderDetails() {
        var _a;
        const transaction = (_a = this.transactions) === null || _a === void 0 ? void 0 : _a[0];
        if (!transaction) {
            return null;
        }
        return (h("div", { class: "transaction-toast-details-info" }, transaction.directionLabel && h("span", { class: "transaction-toast-details-info-text" }, transaction.directionLabel), h("div", { class: "transaction-toast-details-info-icon" }, transaction.interactorAsset ? h("img", { src: transaction.interactorAsset, alt: "Service icon", loading: "lazy" }) : h("mvx-default-transaction-icon-small", null)), h("mvx-trim-text", { text: transaction.interactor, class: "transaction-toast-details-info-text" })));
    }
    render() {
        var _a;
        const { title, hasCloseButton } = this.toastDataState;
        const transaction = this.transactions[0];
        const showAmount = this.transactions.length === 1 && (transaction === null || transaction === void 0 ? void 0 : transaction.amount);
        const showExplorerLinkButton = (transaction === null || transaction === void 0 ? void 0 : transaction.link) && this.transactions.length === 1;
        return (h("div", { key: '9c7236e5d02b6a879906faadcd8dd81bfbbe9fe6', class: {
                'transaction-toast-content-wrapper': true,
                'full-width': this.fullWidth,
            }, "data-testid": DataTestIdsEnum.transactionToastContent }, h("div", { key: '700c883392dbd2f62a460bcf73ab7ae3d70a65cb', class: "transaction-toast-content" }, h("div", { key: 'd4c4586670d0d4dd3e53d8cf4b044be499717f1f', class: "transaction-toast-icon" }, this.renderPrimaryIcon()), h("div", { key: '1e522861bf95ca4701454e8f918bfeff052a2bf6', class: "transaction-toast-details" }, h("div", { key: '50d76d81e5b09652249280e50c7e93cd720d80ad', class: "transaction-toast-details-header" }, h("h4", { key: '4f744e83dc712068816c3aa5de391ac53c4ba695', class: {
                'transaction-toast-title': true,
                'transaction-toast-title-short': Boolean(showAmount),
            } }, title || ((_a = transaction === null || transaction === void 0 ? void 0 : transaction.action) === null || _a === void 0 ? void 0 : _a.name)), showAmount && h("div", { key: '545e6b77ff917b9944dea2ea46522e7a0e0b7f45', class: "transaction-toast-amount" }, transaction.amount)), this.renderDetails()), hasCloseButton && h("fa-icon", { key: 'f1a62e77a719d70a3ab19cf9a51cbfa311c58bd5', icon: faTimes, class: "transaction-toast-close-icon", onClick: this.handleDeleteToast.bind(this) }), !hasCloseButton && showExplorerLinkButton && h("mvx-explorer-link", { key: '29ab2e2995b11f00f2db904c2ea1b4fec2e76b40', link: transaction.link, class: "transaction-toast-action-button" })), !showExplorerLinkButton && h("mvx-transaction-toast-details", { key: 'dadae63217d4549656164a724b78f269052c0fb2', transactions: this.transactions, processedTransactionsStatus: this.processedTransactionsStatus })));
    }
};
TransactionToastContent.style = transactionToastContentCss;

const transactionToastProgressCss = "@keyframes progressiveFixedWidthExpansion{from{width:min(var(--start-width, 0%), 80%)}to{width:80%}}@keyframes progressiveInfiniteWidthExpansion{from{width:min(var(--start-width, 0%), 100%)}to{width:100%}}@keyframes quickWidthExpansion{from{width:0%}to{width:100%}}.transaction-toast-progress{position:relative;width:100%;height:100%;display:block}.transaction-toast-bar-wrapper{position:absolute;left:4px;right:4px;bottom:5px;display:flex;overflow:hidden;pointer-events:none;background:var(--mx-tx-text-secondary);border-radius:20px;height:4px;opacity:1;transition:opacity 250ms ease-in;margin:0;z-index:9999}.transaction-toast-bar{height:100%;position:absolute;top:0;bottom:0;left:0;border-radius:20px}.transaction-toast-bar-fixed{width:min(var(--start-width, 0%), 50%);background:var(--mx-accent);animation:progressiveFixedWidthExpansion var(--animation-duration, 6s) cubic-bezier(0.5, 0.95, 0, 0.35) forwards}.transaction-toast-bar.infinite{width:20%;display:flex;background:var(--mx-accent)}.transaction-toast-bar.infinite .transaction-toast-bar-line{width:0;height:100%;position:relative;background:var(--mx-accent);border-radius:20px;animation:progressiveInfiniteWidthExpansion var(--animation-duration, 60s) cubic-bezier(0.1, 0.95, 0.25, 0.75) forwards;animation-delay:var(--animation-delay, 6s)}.transaction-toast-bar.fill{width:0;position:absolute;background:var(--mx-accent);border-radius:20px}.transaction-toast-bar.fill.animate{animation:quickWidthExpansion 250ms linear forwards}.transaction-toast-bar-content{position:relative;z-index:10;padding-bottom:4px}";

const DEFAULT_INFINITE_ANIMATION_DURATION = 30;
const ToastProgress = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
        this.currentTimestamp = Date.now() / 1000;
        this.hasTimeElapsed = false;
        this.expectedTransactionDuration = 0;
        this.secondsPassedSinceStart = 0;
        this.shouldShowProgressBar = false;
        this.percentagePassedSinceStart = 0;
        this.shouldQuickFill = false;
        this.infiniteProgressDelay = 0;
        this.infinitePercentagePassedSinceStart = 0;
        this.infinitePercentageAnimationDuration = DEFAULT_INFINITE_ANIMATION_DURATION + (this.endTime - this.startTime) * 2;
    }
    componentWillLoad() {
        this.updateProgress();
    }
    handleTimeChange() {
        this.updateProgress();
    }
    updateProgress() {
        this.shouldShowProgressBar = Boolean(this.endTime) && Boolean(this.startTime);
        if (!this.shouldShowProgressBar) {
            this.shouldQuickFill = true;
            this.timeElapsedTimeoutReference = setTimeout(() => (this.hasTimeElapsed = true), 500);
            return;
        }
        this.currentTimestamp = Date.now() / 1000;
        this.expectedTransactionDuration = this.endTime - this.startTime;
        this.secondsPassedSinceStart = this.currentTimestamp - this.startTime;
        this.percentagePassedSinceStart = this.expectedTransactionDuration > 0 ? (this.secondsPassedSinceStart / this.expectedTransactionDuration) * 100 : 0;
        this.infiniteProgressDelay = Math.max(0, this.expectedTransactionDuration - this.secondsPassedSinceStart);
        this.infinitePercentagePassedSinceStart = (this.secondsPassedSinceStart / (this.expectedTransactionDuration + this.infinitePercentageAnimationDuration)) * 100;
    }
    disconnectedCallback() {
        if (this.timeElapsedTimeoutReference) {
            clearTimeout(this.timeElapsedTimeoutReference);
        }
    }
    render() {
        return (h(Fragment, { key: 'db63fa5477f9821fe10d93ca87b50a9ba911609a' }, h("div", { key: '21dd676a9c365e393e0d5fc470befd6fd9f39ce6', class: "transaction-toast-bar-wrapper", style: { opacity: this.hasTimeElapsed ? '0' : '1' } }, h("div", { key: '7ad99e0a6120682d37d51d5832db5836879c6636', class: "transaction-toast-bar-fixed", style: {
                '--animation-duration': `${this.expectedTransactionDuration}s`,
                '--start-width': `${this.percentagePassedSinceStart}%`,
            } }), h("div", { key: '1f8dad80201e843d6aa0f54e720d88337419938d', class: "transaction-toast-bar infinite" }, h("div", { key: '28b9b224f3295d7613d2d4a805a7b2972b3c130e', class: "transaction-toast-bar-line", style: {
                '--start-width': `${this.infinitePercentagePassedSinceStart}%`,
                '--animation-duration': `${this.infinitePercentageAnimationDuration}s`,
                '--animation-delay': `${this.infiniteProgressDelay}s`,
            } })), h("div", { key: '3f5ba0353ca631bb472ff853bd9fd0727d0dee61', class: classNames('transaction-toast-bar fill', {
                animate: this.shouldQuickFill,
            }) })), h("div", { key: 'a15a928b91812e32b9536537235b06231b14f391', class: "transaction-toast-bar-content" }, h("slot", { key: '5d4c02111114b4b48d6ec32d4dc5e9fa35027402' }))));
    }
    static get watchers() { return {
        "startTime": ["handleTimeChange"],
        "endTime": ["handleTimeChange"]
    }; }
};
ToastProgress.style = transactionToastProgressCss;

export { TransactionToast as mvx_transaction_toast, TransactionToastContent as mvx_transaction_toast_content, ToastProgress as mvx_transaction_toast_progress };
//# sourceMappingURL=mvx-transaction-toast.mvx-transaction-toast-content.mvx-transaction-toast-progress.entry.js.map

//# sourceMappingURL=mvx-transaction-toast_3.entry.js.map