import { p as proxyCustomElement, H, f as forceUpdate, h } from './p-FAOyWG8K.js';
import { D as DataTestIdsEnum } from './p-uM8_L1mr.js';
import { L as LedgerConnectBase, a as LedgerConnectEventsEnum } from './p-D2xxRwLD.js';
import { d as defineCustomElement$8 } from './p-aqiOFbXW.js';
import { d as defineCustomElement$7 } from './p-BhfIuGAV.js';
import { d as defineCustomElement$6 } from './p-C-O31jhY.js';
import { d as defineCustomElement$5 } from './p-BRxwV0Ra.js';
import { d as defineCustomElement$4 } from './p-KLlPfyBx.js';
import { d as defineCustomElement$3 } from './p-BVrnSDXE.js';
import { d as defineCustomElement$2 } from './p-BWYxoN3R.js';

const ledgerConnectPanelCss = ".ledger-connect-content{height:100%;display:flex;flex-direction:column;padding:24px}.ledger-connect-header{margin-bottom:24px}.ledger-connect-header h2{font-size:24px;font-weight:500;margin:0 0 8px 0;color:#000}.ledger-connect-header h4{font-size:16px;font-weight:400;margin:0;color:#666}.ledger-connect-body{flex:1;overflow-y:auto}";

const LedgerConnectPanel = /*@__PURE__*/ proxyCustomElement(class LedgerConnectPanel extends H {
    constructor() {
        super();
        this.__registerHost();
        this.data = {
            accountScreenData: null,
            confirmScreenData: null,
            connectScreenData: {},
        };
        this.isOpen = false;
        this.selectedIndex = 0;
    }
    componentWillLoad() {
        this.ledgerConnectBase = new LedgerConnectBase(this.data);
    }
    componentDidLoad() {
        this.ledgerConnectBase.subscribeEventBus(this.getEventBusSubscription());
        this.ledgerConnectBase.eventBus.subscribe(LedgerConnectEventsEnum.OPEN_LEDGER_CONNECT_PANEL, this.handleOpen.bind(this));
        this.ledgerConnectBase.eventBus.subscribe(LedgerConnectEventsEnum.CLOSE_LEDGER_CONNECT_PANEL, this.onClose.bind(this, { isUserClick: false }));
    }
    disconnectedCallback() {
        this.ledgerConnectBase.unsubscribeEventBus(this.getEventBusSubscription());
        this.ledgerConnectBase.eventBus.unsubscribe(LedgerConnectEventsEnum.OPEN_LEDGER_CONNECT_PANEL, this.handleOpen.bind(this));
        this.ledgerConnectBase.eventBus.unsubscribe(LedgerConnectEventsEnum.CLOSE_LEDGER_CONNECT_PANEL, this.onClose.bind(this, { isUserClick: false }));
    }
    handleConnect() {
        this.ledgerConnectBase.eventBus.publish(LedgerConnectEventsEnum.CONNECT_DEVICE);
    }
    handleOpen() {
        this.isOpen = true;
    }
    handleClose() {
        this.isOpen = false;
        this.onClose({ isUserClick: true });
    }
    onClose(props = { isUserClick: true }) {
        this.isOpen = false;
        if (props.isUserClick) {
            this.ledgerConnectBase.eventBus.publish(LedgerConnectEventsEnum.CLOSE_LEDGER_CONNECT_PANEL);
        }
    }
    accessWallet() {
        this.ledgerConnectBase.accessWallet();
    }
    selectAccount(index) {
        this.ledgerConnectBase.selectAccount(index);
        this.selectedIndex = this.ledgerConnectBase.selectedIndex;
    }
    async nextPage() {
        this.ledgerConnectBase.nextPage();
    }
    async prevPage() {
        this.ledgerConnectBase.prevPage();
    }
    async getEventBus() {
        return this.ledgerConnectBase.getEventBus();
    }
    getEventBusSubscription() {
        return {
            closeFn: () => this.onClose({ isUserClick: false }),
            forceUpdateFn: () => {
                this.data = this.ledgerConnectBase.data;
                forceUpdate(this);
            },
        };
    }
    getHeaderContent(accountScreenData, confirmScreenData) {
        if (accountScreenData) {
            return (h("div", { class: "ledger-connect-header" }, h("h2", { "data-testid": `${DataTestIdsEnum.addressTableContainer}Title` }, "Access your wallet"), h("h4", { "data-testid": `${DataTestIdsEnum.addressTableContainer}SubTitle` }, "Choose the wallet you want to access")));
        }
        if (confirmScreenData) {
            return (h("div", { class: "ledger-connect-header" }, h("h2", null, "Confirm"), h("h4", null, "Confirm Ledger Address")));
        }
        return (h("div", { class: "ledger-connect-header" }, h("h2", null, "Connect Ledger"), h("h4", null, "Unlock your device & open the MultiversX App")));
    }
    getBodyContent(accountScreenData, confirmScreenData, connectScreenData) {
        if (accountScreenData) {
            return (h("mvx-ledger-account-screen", { accountScreenData: accountScreenData, selectedIndex: this.selectedIndex, onSelectAccount: (event) => this.selectAccount(event.detail), onAccessWallet: () => this.accessWallet(), onPrevPage: () => this.prevPage(), onNextPage: () => this.nextPage() }));
        }
        if (confirmScreenData) {
            return h("mvx-ledger-confirm-screen", { confirmScreenData: confirmScreenData });
        }
        return h("mvx-ledger-connect-screen", { connectScreenData: connectScreenData, onConnect: this.handleConnect.bind(this) });
    }
    render() {
        const { accountScreenData, confirmScreenData, connectScreenData } = this.data;
        const bodyContent = this.getBodyContent(accountScreenData, confirmScreenData, connectScreenData);
        return (h("mvx-side-panel", { key: '35d688857b47ff7693df2f41a151569184ccd0c8', isOpen: this.isOpen, panelClassName: "ledger-connect-panel", onClose: this.handleClose.bind(this) }, h("div", { key: '1af25d0155b98064ea42928a55b995c9f92d294d', class: "ledger-connect-content" }, this.getHeaderContent(accountScreenData, confirmScreenData), h("div", { key: 'ce2e83b078c020e7bb2e40a84e6f701988b12ef1', class: "ledger-connect-body" }, bodyContent))));
    }
    static get style() { return ledgerConnectPanelCss; }
}, [0, "mvx-ledger-connect-panel", {
        "data": [16],
        "isOpen": [32],
        "selectedIndex": [32],
        "getEventBus": [64]
    }]);
function defineCustomElement$1() {
    if (typeof customElements === "undefined") {
        return;
    }
    const components = ["mvx-ledger-connect-panel", "mvx-back-arrow-icon", "mvx-close-icon", "mvx-generic-spinner", "mvx-ledger-account-screen", "mvx-ledger-confirm-screen", "mvx-ledger-connect-screen", "mvx-side-panel"];
    components.forEach(tagName => { switch (tagName) {
        case "mvx-ledger-connect-panel":
            if (!customElements.get(tagName)) {
                customElements.define(tagName, LedgerConnectPanel);
            }
            break;
        case "mvx-back-arrow-icon":
            if (!customElements.get(tagName)) {
                defineCustomElement$8();
            }
            break;
        case "mvx-close-icon":
            if (!customElements.get(tagName)) {
                defineCustomElement$7();
            }
            break;
        case "mvx-generic-spinner":
            if (!customElements.get(tagName)) {
                defineCustomElement$6();
            }
            break;
        case "mvx-ledger-account-screen":
            if (!customElements.get(tagName)) {
                defineCustomElement$5();
            }
            break;
        case "mvx-ledger-confirm-screen":
            if (!customElements.get(tagName)) {
                defineCustomElement$4();
            }
            break;
        case "mvx-ledger-connect-screen":
            if (!customElements.get(tagName)) {
                defineCustomElement$3();
            }
            break;
        case "mvx-side-panel":
            if (!customElements.get(tagName)) {
                defineCustomElement$2();
            }
            break;
    } });
}

const MvxLedgerConnectPanel = LedgerConnectPanel;
const defineCustomElement = defineCustomElement$1;

export { MvxLedgerConnectPanel, defineCustomElement };
//# sourceMappingURL=mvx-ledger-connect-panel.js.map

//# sourceMappingURL=mvx-ledger-connect-panel.js.map