import { p as proxyCustomElement, H, f as forceUpdate, h } from './p-FAOyWG8K.js';
import { E as EventBus } from './p-S9juR7eS.js';
import { s as state, r as resetState } from './p-B8ALvP0A.js';
import { d as defineCustomElement$5 } from './p-aqiOFbXW.js';
import { d as defineCustomElement$4 } from './p-BhfIuGAV.js';
import { d as defineCustomElement$3 } from './p-C-O31jhY.js';
import { d as defineCustomElement$2 } from './p-BWYxoN3R.js';

var SignEventsEnum;
(function (SignEventsEnum) {
    SignEventsEnum["CONFIRM"] = "CONFIRM";
    SignEventsEnum["BACK"] = "BACK";
    SignEventsEnum["DATA_UPDATE"] = "DATA_UPDATE";
    SignEventsEnum["SET_PPU"] = "SET_PPU";
    SignEventsEnum["OPEN_SIGN_TRANSACTIONS_PANEL"] = "OPEN_SIGN_TRANSACTIONS_PANEL";
    SignEventsEnum["CLOSE_SIGN_TRANSACTIONS_PANEL"] = "CLOSE_SIGN_TRANSACTIONS_PANEL";
})(SignEventsEnum || (SignEventsEnum = {}));

const signTransactionsPanelCss = "*{margin:0;padding:0;box-sizing:border-box}.transaction-header-container{display:flex;flex-direction:column}.loading-spinner{display:flex;justify-content:center;align-items:center;min-height:350px}.sign-transactions-panel{width:450px;max-width:100%;padding:0;background-color:#ffffff;box-shadow:0 4px 12px rgba(0, 0, 0, 0.15)}.sign-transactions-content{display:flex;flex-direction:column;height:100%;padding:24px}.sign-transactions-header{margin-bottom:24px;border-bottom:1px solid rgba(0, 0, 0, 0.1);padding-bottom:16px}.sign-transactions-header h2{font-size:20px;font-weight:600;margin-bottom:8px}.sign-transactions-header h4{font-size:14px;font-weight:400;color:rgba(0, 0, 0, 0.6)}.sign-transactions-body{flex:1;overflow-y:auto}";

const signScreens = {
    FungibleESDT: 'token-component',
    SemiFungibleESDT: 'fungible-component',
    NonFungibleESDT: 'fungible-component',
    MetaESDT: 'token-component',
};
const SignTransactionsPanel = /*@__PURE__*/ proxyCustomElement(class SignTransactionsPanel extends H {
    constructor() {
        super();
        this.__registerHost();
        this.eventBus = new EventBus();
        this.isOpen = false;
        this.data = {
            commonData: {
                egldLabel: '',
                feeLimit: '',
                feeInFiatLimit: '',
                transactionsCount: 0,
                currentIndex: 0,
                ppuOptions: [],
            },
            tokenTransaction: null,
            nftTransaction: null,
            sftTransaction: null,
        };
    }
    componentWillLoad() {
        state.onCancel = () => {
            this.onClose({ isUserClick: true });
        };
        state.onConfirm = () => {
            this.eventBus.publish(SignEventsEnum.CONFIRM);
        };
        state.onBack = () => {
            this.eventBus.publish(SignEventsEnum.BACK);
        };
        state.onSetPpu = (ppu) => {
            this.eventBus.publish(SignEventsEnum.SET_PPU, ppu);
        };
    }
    componentDidLoad() {
        this.eventBus.subscribe(SignEventsEnum.DATA_UPDATE, this.dataUpdate.bind(this));
        this.eventBus.subscribe(SignEventsEnum.OPEN_SIGN_TRANSACTIONS_PANEL, this.handleOpen.bind(this));
        this.eventBus.subscribe(SignEventsEnum.CLOSE_SIGN_TRANSACTIONS_PANEL, this.onClose.bind(this, { isUserClick: false }));
    }
    disconnectedCallback() {
        resetState();
        this.eventBus.unsubscribe(SignEventsEnum.DATA_UPDATE, this.dataUpdate.bind(this));
        this.eventBus.unsubscribe(SignEventsEnum.OPEN_SIGN_TRANSACTIONS_PANEL, this.handleOpen.bind(this));
        this.eventBus.unsubscribe(SignEventsEnum.CLOSE_SIGN_TRANSACTIONS_PANEL, this.onClose.bind(this, { isUserClick: false }));
    }
    handleOpen() {
        this.isOpen = true;
    }
    handleClose() {
        this.isOpen = false;
        this.onClose({ isUserClick: true });
    }
    onClose(props = { isUserClick: true }) {
        this.isOpen = false;
        resetState();
        if (props.isUserClick) {
            this.eventBus.publish(SignEventsEnum.CLOSE_SIGN_TRANSACTIONS_PANEL);
        }
    }
    dataUpdate(payload) {
        this.data = Object.assign({}, payload);
        forceUpdate(this);
    }
    onDataChange(data) {
        for (const key in data) {
            if (Object.prototype.hasOwnProperty.call(state, key)) {
                state[key] = data[key];
            }
        }
        state.isWaitingForSignature = false;
        state.isLoading = false;
    }
    async getEventBus() {
        return this.eventBus;
    }
    render() {
        const { commonData, isLoading } = state;
        const { tokenType, currentIndex, transactionsCount } = commonData;
        const SignScreen = signScreens[tokenType];
        return (h("mvx-side-panel", { key: '509b13edb464c57199f961740bd9d83149434064', isOpen: this.isOpen, panelClassName: "sign-transactions-panel", onClose: this.handleClose.bind(this) }, h("div", { key: 'aa929cfd9f98130efd7431d713a4a45a3df08dca', class: "sign-transactions-content" }, h("div", { key: '62fa7f9f7052724d8493a15544a80c44c73b1b65', class: "sign-transactions-header" }, h("h2", { key: '908edd8f9f07b4485a2711053a7807ed02dbb3d1' }, "Sign transaction"), h("h4", { key: '80bb8619e0480b3e7314c3718ffdd4b305e36f0d' }, "Transaction ", currentIndex + 1, " of ", transactionsCount)), h("div", { key: '188051f296c564f7cd1a2c9a157829a11ee8419c', class: "sign-transactions-body" }, isLoading ? (h("div", { class: "loading-spinner" }, h("mvx-generic-spinner", null))) : (h(SignScreen, null))))));
    }
    static get watchers() { return {
        "data": ["onDataChange"]
    }; }
    static get style() { return signTransactionsPanelCss; }
}, [0, "mvx-sign-transactions-panel", {
        "data": [16],
        "isOpen": [32],
        "getEventBus": [64]
    }, undefined, {
        "data": ["onDataChange"]
    }]);
function defineCustomElement$1() {
    if (typeof customElements === "undefined") {
        return;
    }
    const components = ["mvx-sign-transactions-panel", "mvx-back-arrow-icon", "mvx-close-icon", "mvx-generic-spinner", "mvx-side-panel"];
    components.forEach(tagName => { switch (tagName) {
        case "mvx-sign-transactions-panel":
            if (!customElements.get(tagName)) {
                customElements.define(tagName, SignTransactionsPanel);
            }
            break;
        case "mvx-back-arrow-icon":
            if (!customElements.get(tagName)) {
                defineCustomElement$5();
            }
            break;
        case "mvx-close-icon":
            if (!customElements.get(tagName)) {
                defineCustomElement$4();
            }
            break;
        case "mvx-generic-spinner":
            if (!customElements.get(tagName)) {
                defineCustomElement$3();
            }
            break;
        case "mvx-side-panel":
            if (!customElements.get(tagName)) {
                defineCustomElement$2();
            }
            break;
    } });
}

const MvxSignTransactionsPanel = SignTransactionsPanel;
const defineCustomElement = defineCustomElement$1;

export { MvxSignTransactionsPanel, defineCustomElement };
//# sourceMappingURL=mvx-sign-transactions-panel.js.map

//# sourceMappingURL=mvx-sign-transactions-panel.js.map