import { h, p as proxyCustomElement, H, c as createEvent, F as Fragment } from './p-FAOyWG8K.js';
import { D as DataTestIdsEnum } from './p-uM8_L1mr.js';
import { d as defineCustomElement$1 } from './p-C-O31jhY.js';

function trimAddress(s) {
    const firstFour = s.slice(0, 6);
    const lastFour = s.slice(-6);
    return `${firstFour}...${lastFour}`;
}
const renderAccounts = ({ shownAccounts = [], onSelectAccount, selectedIndex }) => {
    return (h("div", { class: "account-list", "data-testid": DataTestIdsEnum.addressTableContainer },
        h("div", { class: "account-header" },
            h("div", { class: "account-header-item" }, "Address"),
            h("div", { class: "account-header-item" }, "Balance"),
            h("div", { class: "account-header-item" }, "#")),
        shownAccounts.map(account => (h("div", { class: "account-row", onClick: () => onSelectAccount(account.index) },
            h("div", { class: "address-row-item-data " },
                h("input", { type: "radio", name: "account", checked: account.index === selectedIndex, value: account.index }),
                h("span", { class: "address" }, trimAddress(account.address))),
            h("div", { class: "address-row-item-data" }, account.balance),
            h("div", { class: "address-row-item-data" }, account.index))))));
};

const ledgerAccountScreenScss = ".account-header{display:flex;align-items:center;background-color:#ced4da;line-height:1;padding:16px;text-align:left;font-size:14px;border-radius:8px;padding-right:20px}.account-header-item{flex:1}.account-header-item:first-child{width:55%;max-width:55%}.account-header-item:last-child{width:32px;max-width:32px;flex-basis:32px;text-align:center}.account-list{width:100%;min-height:300px;max-height:300px;position:relative;overflow:auto}.account-row{display:flex;align-items:center;padding:16px;border-radius:8px;cursor:pointer}.account-row:hover{background-color:#f5f5f5}.address-row-item-data{font-size:14px;line-height:1;flex:1;text-align:left;display:flex;align-items:center;padding-right:16px}.address-row-item-data:last-child{width:32px;max-width:32px;flex-basis:32px;text-align:center;justify-content:center;padding-right:0}.navigation{display:flex;justify-content:center;gap:10rem;margin-top:20px}.navigation-button{background:transparent;border:none;cursor:pointer}.navigation-button:hover{color:#1a56db}.navigation-button:disabled{color:#737373;pointer-events:none}.access-button{display:block;width:200px;margin:20px auto;padding:12px;background-color:#1a56db;color:white;border:none;border-radius:8px;cursor:pointer}.access-button:disabled{background-color:#a1a1a1;color:#e0e0e0;cursor:not-allowed;opacity:0.6;box-shadow:none;transform:none}";

const LedgerAccountScreen = /*@__PURE__*/ proxyCustomElement(class LedgerAccountScreen extends H {
    constructor() {
        super();
        this.__registerHost();
        this.selectAccount = createEvent(this, "selectAccount");
        this.nextPage = createEvent(this, "nextPage");
        this.prevPage = createEvent(this, "prevPage");
        this.accessWallet = createEvent(this, "accessWallet");
    }
    render() {
        const isSelectedIndexOnPage = this.accountScreenData.accounts.some(({ index }) => index === this.selectedIndex);
        const accountsList = this.accountScreenData.isLoading || this.accountScreenData.accounts.length === 0 ? (h("mvx-generic-spinner", { "data-testid": DataTestIdsEnum.ledgerLoading })) : (renderAccounts({
            shownAccounts: this.accountScreenData.accounts,
            onSelectAccount: (index) => this.selectAccount.emit(index),
            selectedIndex: this.selectedIndex,
        }));
        return (h(Fragment, { key: 'b0ec8c215b0f4dede098b71c6051ba3c8c8fdeb0' }, accountsList, !this.accountScreenData.isLoading && this.accountScreenData.accounts.length !== 0 && (h(Fragment, { key: '84bed13ab30037ac68fd1d600dcbbc27338e7a18' }, h("div", { key: '084ceab80f731d6e02d632f26ae5db25efd0f011', class: "navigation" }, h("button", { key: 'feef8b25f45694005b3d653a38f68eefe48bdedd', onClick: () => this.prevPage.emit(), disabled: this.accountScreenData.startIndex <= 0, "data-testid": DataTestIdsEnum.prevBtn, class: "navigation-button" }, '< ', " Prev"), h("button", { key: 'b5fe944de4a207cda7c0e56d1947798089fa82b7', onClick: () => this.nextPage.emit(), "data-testid": DataTestIdsEnum.nextBtn, class: "navigation-button" }, "Next", ' >')), h("button", { key: '977d31454dfdaa77688888b539a014c5c44ed33d', "data-testid": DataTestIdsEnum.confirmBtn, class: "access-button", onClick: () => this.accessWallet.emit(), disabled: !isSelectedIndexOnPage }, "Access Wallet")))));
    }
    static get style() { return ledgerAccountScreenScss; }
}, [0, "mvx-ledger-account-screen", {
        "accountScreenData": [16, "account-screen-data"],
        "selectedIndex": [2, "selected-index"]
    }]);
function defineCustomElement() {
    if (typeof customElements === "undefined") {
        return;
    }
    const components = ["mvx-ledger-account-screen", "mvx-generic-spinner"];
    components.forEach(tagName => { switch (tagName) {
        case "mvx-ledger-account-screen":
            if (!customElements.get(tagName)) {
                customElements.define(tagName, LedgerAccountScreen);
            }
            break;
        case "mvx-generic-spinner":
            if (!customElements.get(tagName)) {
                defineCustomElement$1();
            }
            break;
    } });
}

export { LedgerAccountScreen as L, defineCustomElement as d };
//# sourceMappingURL=p-BRxwV0Ra.js.map

//# sourceMappingURL=p-BRxwV0Ra.js.map