import { p as proxyCustomElement, H, h } from './p-FAOyWG8K.js';
import { c as faCheck, h as faCopy } from './p-LoDd7cPH.js';
import { d as defineCustomElement$1 } from './p-2EAIMxwa.js';

const isWindowAvailable = () => typeof window != 'undefined' && typeof (window === null || window === void 0 ? void 0 : window.location) != 'undefined';

function fallbackCopyTextToClipboard(text) {
    let success = false;
    if (!document || !document.body) {
        console.error('Document or document.body is not available');
        return success;
    }
    const textArea = document.createElement('textarea');
    textArea.value = text;
    textArea.style.position = 'fixed';
    textArea.style.left = '-9999px';
    textArea.style.top = '0';
    document.body.appendChild(textArea);
    try {
        textArea.focus();
        textArea.setSelectionRange(0, textArea.value.length);
        success = document.execCommand('copy');
    }
    catch (err) {
        console.error('Fallback: Oops, unable to copy', err);
    }
    finally {
        document.body.removeChild(textArea);
    }
    return success;
}
async function copyToClipboard(text) {
    if (!isWindowAvailable()) {
        return false;
    }
    let success = false;
    if (!navigator.clipboard) {
        success = fallbackCopyTextToClipboard(text);
    }
    else {
        success = await navigator.clipboard.writeText(text).then(function done() {
            return true;
        }, function error(err) {
            console.error('Async: Could not copy text: ', err);
            return false;
        });
    }
    return success;
}

const copyButtonCss = ".copy-button{color:#6c757d}";

const CopyButton = /*@__PURE__*/ proxyCustomElement(class CopyButton extends H {
    constructor() {
        super();
        this.__registerHost();
        this.class = 'copy-button';
        this.iconClass = 'copy-button-icon';
        this.isSuccess = false;
        this.handleClick = async (event) => {
            event.preventDefault();
            event.stopPropagation();
            const trimmedText = this.text ? this.text.trim() : this.text;
            const success = await copyToClipboard(trimmedText);
            this.isSuccess = success;
            if (success) {
                this.timeoutId = window.setTimeout(() => {
                    this.isSuccess = false;
                }, 1000);
            }
        };
    }
    disconnectedCallback() {
        // Clear the timeout if the component is unmounted
        if (this.timeoutId) {
            clearTimeout(this.timeoutId);
            this.timeoutId = undefined; // Reset the timeout ID
        }
    }
    render() {
        var _a, _b;
        const copyIcon = (_a = this.copyIcon) !== null && _a !== void 0 ? _a : faCopy;
        const successIcon = (_b = this.successIcon) !== null && _b !== void 0 ? _b : faCheck;
        return (h("a", { key: '24db0c49002be78e6eff6cbd14ff53b4a0a866a7', href: "/#", class: this.class, onClick: this.handleClick }, h("mvx-fa-icon", { key: '06625249df645dadafdf18e1607911e38d6e43a8', icon: this.isSuccess ? successIcon : copyIcon, class: this.iconClass })));
    }
    static get style() { return copyButtonCss; }
}, [0, "mvx-copy-button", {
        "class": [1],
        "iconClass": [1, "icon-class"],
        "copyIcon": [16, "copy-icon"],
        "successIcon": [16, "success-icon"],
        "text": [1],
        "isSuccess": [32]
    }]);
function defineCustomElement() {
    if (typeof customElements === "undefined") {
        return;
    }
    const components = ["mvx-copy-button", "mvx-fa-icon"];
    components.forEach(tagName => { switch (tagName) {
        case "mvx-copy-button":
            if (!customElements.get(tagName)) {
                customElements.define(tagName, CopyButton);
            }
            break;
        case "mvx-fa-icon":
            if (!customElements.get(tagName)) {
                defineCustomElement$1();
            }
            break;
    } });
}

export { CopyButton as C, defineCustomElement as d };
//# sourceMappingURL=p-C61O5PTR.js.map

//# sourceMappingURL=p-C61O5PTR.js.map