import { p as proxyCustomElement, H, h, F as Fragment } from './p-FAOyWG8K.js';
import { c as classNames } from './p-Bl7qiiAR.js';

const transactionToastProgressCss = "@keyframes progressiveFixedWidthExpansion{from{width:min(var(--start-width, 0%), 80%)}to{width:80%}}@keyframes progressiveInfiniteWidthExpansion{from{width:min(var(--start-width, 0%), 100%)}to{width:100%}}@keyframes quickWidthExpansion{from{width:0%}to{width:100%}}.transaction-toast-progress{position:relative;width:100%;height:100%;display:block}.transaction-toast-bar-wrapper{position:absolute;left:4px;right:4px;bottom:5px;display:flex;overflow:hidden;pointer-events:none;background:var(--mx-tx-text-secondary);border-radius:20px;height:4px;opacity:1;transition:opacity 250ms ease-in;margin:0;z-index:9999}.transaction-toast-bar{height:100%;position:absolute;top:0;bottom:0;left:0;border-radius:20px}.transaction-toast-bar-fixed{width:min(var(--start-width, 0%), 50%);background:var(--mx-accent);animation:progressiveFixedWidthExpansion var(--animation-duration, 6s) cubic-bezier(0.5, 0.95, 0, 0.35) forwards}.transaction-toast-bar.infinite{width:20%;display:flex;background:var(--mx-accent)}.transaction-toast-bar.infinite .transaction-toast-bar-line{width:0;height:100%;position:relative;background:var(--mx-accent);border-radius:20px;animation:progressiveInfiniteWidthExpansion var(--animation-duration, 60s) cubic-bezier(0.1, 0.95, 0.25, 0.75) forwards;animation-delay:var(--animation-delay, 6s)}.transaction-toast-bar.fill{width:0;position:absolute;background:var(--mx-accent);border-radius:20px}.transaction-toast-bar.fill.animate{animation:quickWidthExpansion 250ms linear forwards}.transaction-toast-bar-content{position:relative;z-index:10;padding-bottom:4px}";

const DEFAULT_INFINITE_ANIMATION_DURATION = 30;
const ToastProgress = /*@__PURE__*/ proxyCustomElement(class ToastProgress extends H {
    constructor() {
        super();
        this.__registerHost();
        this.currentTimestamp = Date.now() / 1000;
        this.hasTimeElapsed = false;
        this.expectedTransactionDuration = 0;
        this.secondsPassedSinceStart = 0;
        this.shouldShowProgressBar = false;
        this.percentagePassedSinceStart = 0;
        this.shouldQuickFill = false;
        this.infiniteProgressDelay = 0;
        this.infinitePercentagePassedSinceStart = 0;
        this.infinitePercentageAnimationDuration = DEFAULT_INFINITE_ANIMATION_DURATION + (this.endTime - this.startTime) * 2;
    }
    componentWillLoad() {
        this.updateProgress();
    }
    handleTimeChange() {
        this.updateProgress();
    }
    updateProgress() {
        this.shouldShowProgressBar = Boolean(this.endTime) && Boolean(this.startTime);
        if (!this.shouldShowProgressBar) {
            this.shouldQuickFill = true;
            this.timeElapsedTimeoutReference = setTimeout(() => (this.hasTimeElapsed = true), 500);
            return;
        }
        this.currentTimestamp = Date.now() / 1000;
        this.expectedTransactionDuration = this.endTime - this.startTime;
        this.secondsPassedSinceStart = this.currentTimestamp - this.startTime;
        this.percentagePassedSinceStart = this.expectedTransactionDuration > 0 ? (this.secondsPassedSinceStart / this.expectedTransactionDuration) * 100 : 0;
        this.infiniteProgressDelay = Math.max(0, this.expectedTransactionDuration - this.secondsPassedSinceStart);
        this.infinitePercentagePassedSinceStart = (this.secondsPassedSinceStart / (this.expectedTransactionDuration + this.infinitePercentageAnimationDuration)) * 100;
    }
    disconnectedCallback() {
        if (this.timeElapsedTimeoutReference) {
            clearTimeout(this.timeElapsedTimeoutReference);
        }
    }
    render() {
        return (h(Fragment, { key: 'db63fa5477f9821fe10d93ca87b50a9ba911609a' }, h("div", { key: '21dd676a9c365e393e0d5fc470befd6fd9f39ce6', class: "transaction-toast-bar-wrapper", style: { opacity: this.hasTimeElapsed ? '0' : '1' } }, h("div", { key: '7ad99e0a6120682d37d51d5832db5836879c6636', class: "transaction-toast-bar-fixed", style: {
                '--animation-duration': `${this.expectedTransactionDuration}s`,
                '--start-width': `${this.percentagePassedSinceStart}%`,
            } }), h("div", { key: '1f8dad80201e843d6aa0f54e720d88337419938d', class: "transaction-toast-bar infinite" }, h("div", { key: '28b9b224f3295d7613d2d4a805a7b2972b3c130e', class: "transaction-toast-bar-line", style: {
                '--start-width': `${this.infinitePercentagePassedSinceStart}%`,
                '--animation-duration': `${this.infinitePercentageAnimationDuration}s`,
                '--animation-delay': `${this.infiniteProgressDelay}s`,
            } })), h("div", { key: '3f5ba0353ca631bb472ff853bd9fd0727d0dee61', class: classNames('transaction-toast-bar fill', {
                animate: this.shouldQuickFill,
            }) })), h("div", { key: 'a15a928b91812e32b9536537235b06231b14f391', class: "transaction-toast-bar-content" }, h("slot", { key: '5d4c02111114b4b48d6ec32d4dc5e9fa35027402' }))));
    }
    static get watchers() { return {
        "startTime": ["handleTimeChange"],
        "endTime": ["handleTimeChange"]
    }; }
    static get style() { return transactionToastProgressCss; }
}, [4, "mvx-transaction-toast-progress", {
        "startTime": [2, "start-time"],
        "endTime": [2, "end-time"],
        "currentTimestamp": [32],
        "hasTimeElapsed": [32],
        "expectedTransactionDuration": [32],
        "secondsPassedSinceStart": [32],
        "shouldShowProgressBar": [32],
        "percentagePassedSinceStart": [32],
        "shouldQuickFill": [32],
        "infiniteProgressDelay": [32],
        "infinitePercentagePassedSinceStart": [32],
        "infinitePercentageAnimationDuration": [32]
    }, undefined, {
        "startTime": ["handleTimeChange"],
        "endTime": ["handleTimeChange"]
    }]);
function defineCustomElement() {
    if (typeof customElements === "undefined") {
        return;
    }
    const components = ["mvx-transaction-toast-progress"];
    components.forEach(tagName => { switch (tagName) {
        case "mvx-transaction-toast-progress":
            if (!customElements.get(tagName)) {
                customElements.define(tagName, ToastProgress);
            }
            break;
    } });
}

export { ToastProgress as T, defineCustomElement as d };
//# sourceMappingURL=p-DvIsYrF1.js.map

//# sourceMappingURL=p-DvIsYrF1.js.map