import { p as proxyCustomElement, H, h } from './p-FAOyWG8K.js';
import { d as defineCustomElement$2 } from './p-c3G5ZDnd.js';
import { d as defineCustomElement$1 } from './p-B0iWKDlO.js';

// types here need to be synced with the types in sdk-dapp-core providerFactory.types.ts
var ProviderTypeEnum;
(function (ProviderTypeEnum) {
    ProviderTypeEnum["extension"] = "extension";
    ProviderTypeEnum["metamask"] = "metamask";
    ProviderTypeEnum["crossWindow"] = "crossWindow";
    ProviderTypeEnum["walletConnect"] = "walletConnect";
    ProviderTypeEnum["ledger"] = "ledger";
    ProviderTypeEnum["passkey"] = "passkey";
    ProviderTypeEnum["xalias"] = "xalias";
})(ProviderTypeEnum || (ProviderTypeEnum = {}));

const getIsExtensionAvailable = () => {
    const safeWindow = typeof window !== 'undefined' ? window : {};
    // Check if either elrondWallet or multiversxWallet exists and has an extensionId
    return Boolean(safeWindow === null || safeWindow === void 0 ? void 0 : safeWindow.elrondWallet) || Boolean(safeWindow === null || safeWindow === void 0 ? void 0 : safeWindow.multiversxWallet);
};

// Helper to check if MetaMask is available
const getIsMetaMaskAvailable = () => {
    const safeWindow = typeof window !== 'undefined' ? window : {};
    // Check if MetaMask is available through the ethereum object and that isMetaMask is true
    return Boolean((safeWindow === null || safeWindow === void 0 ? void 0 : safeWindow.ethereum) && safeWindow.ethereum.isMetaMask);
};

const unlockButtonScss = ".unlock-button {\n  padding: 0 12px;\n  padding-right: 16px;\n  height: 60px;\n  background: rgba(53, 53, 53, 0.3);\n  display: flex;\n  transition: all 200ms ease;\n  cursor: pointer;\n  align-items: center;\n  gap: 16px;\n\n  &:hover {\n    background: rgba(53, 53, 53, 1);\n  }\n\n  &:first-child {\n    border-top-left-radius: 12px;\n    border-top-right-radius: 12px;\n  }\n\n  &:last-child {\n    border-bottom-left-radius: 12px;\n    border-bottom-right-radius: 12px;\n  }\n\n  .unlock-button-icon {\n    height: 40px;\n    display: flex;\n    align-items: flex-end;\n    justify-content: flex-start;\n    width: 40px;\n  }\n\n  .unlock-button-label {\n    color: #e8e8e8;\n    font-size: 16px;\n    line-height: 1;\n  }\n\n  .unlock-button-status {\n    margin-left: auto;\n    font-weight: 500;\n    font-size: 12px;\n    font-weight: 500;\n    line-height: 1;\n\n    .unlock-button-status-open {\n      color: #23f7dd;\n      padding: 0 8px;\n    }\n\n    .unlock-button-status-install {\n      padding: 4px 8px;\n      border-radius: 20px;\n      border: 1px solid rgba(64, 64, 64, 0.4);\n      background: rgba(11, 11, 11, 0.8);\n      display: flex;\n      align-items: center;\n      gap: 4px;\n\n      .unlock-button-status-install-label {\n        color: #23f7dd;\n      }\n\n      .unlock-button-status-install-icon {\n        display: flex;\n        align-items: center;\n      }\n    }\n  }\n}\n";

const UnlockButton = /*@__PURE__*/ proxyCustomElement(class UnlockButton extends H {
    constructor() {
        super();
        this.__registerHost();
    }
    render() {
        const isExtensionProvider = this.type === ProviderTypeEnum.extension;
        const isMetaMaskProvider = this.type === ProviderTypeEnum.metamask;
        const isDetectableProvider = isExtensionProvider || isMetaMaskProvider;
        const isExtensionInstalled = isExtensionProvider && getIsExtensionAvailable();
        const isMetaMaskInstalled = isMetaMaskProvider && getIsMetaMaskAvailable();
        const shouldShowOpenLabel = isDetectableProvider && (isExtensionInstalled || isMetaMaskInstalled);
        return (h("div", { key: '227b9cdc84b8fb64601689d13e6e3e3e6b84c9a5', class: { 'unlock-button': true, [this.class]: Boolean(this.class) } }, this.icon ? (h("div", { class: "unlock-button-icon" }, this.icon)) : (h("div", { class: "unlock-button-icon" }, h("mvx-multiversx-logo-icon", null))), h("div", { key: '37d3b82db3a25fc64c305d8aed748cbf713cb7a9', class: "unlock-button-label" }, this.label), isDetectableProvider && (h("div", { key: '829c52169644f4b347189efa5246dbf7fbf1ad93', class: "unlock-button-status" }, shouldShowOpenLabel ? (h("div", { class: "unlock-button-status-open" }, "Open")) : (h("div", { class: "unlock-button-status-install" }, h("span", { class: "unlock-button-status-install-label" }, "Install"), h("mvx-arrow-up-right-icon", { class: "unlock-button-status-install-icon" })))))));
    }
    static get style() { return unlockButtonScss; }
}, [0, "mvx-unlock-button", {
        "label": [1],
        "icon": [16],
        "type": [1],
        "class": [1]
    }]);
function defineCustomElement() {
    if (typeof customElements === "undefined") {
        return;
    }
    const components = ["mvx-unlock-button", "mvx-arrow-up-right-icon", "mvx-multiversx-logo-icon"];
    components.forEach(tagName => { switch (tagName) {
        case "mvx-unlock-button":
            if (!customElements.get(tagName)) {
                customElements.define(tagName, UnlockButton);
            }
            break;
        case "mvx-arrow-up-right-icon":
            if (!customElements.get(tagName)) {
                defineCustomElement$2();
            }
            break;
        case "mvx-multiversx-logo-icon":
            if (!customElements.get(tagName)) {
                defineCustomElement$1();
            }
            break;
    } });
}

export { ProviderTypeEnum as P, UnlockButton as U, getIsMetaMaskAvailable as a, defineCustomElement as d, getIsExtensionAvailable as g };
//# sourceMappingURL=p-Z4sMg4la.js.map

//# sourceMappingURL=p-Z4sMg4la.js.map