import { p as proxyCustomElement, H, h } from './p-FAOyWG8K.js';
import { D as DataTestIdsEnum } from './p-uM8_L1mr.js';
import { f as formatAddress } from './index.js';
import { s as state } from './p-B8ALvP0A.js';
import { d as defineCustomElement$1 } from './p-DE2XBunF.js';

const signTransactionComponentCss = "* {\n  margin: 0;\n  padding: 0;\n  box-sizing: border-box;\n}\n\n.transaction-container {\n  display: flex;\n  flex-direction: column;\n  padding: 0rem 1rem 0rem 1rem;\n  gap: 1rem;\n}\n\n.receiver-container {\n  display: flex;\n  flex-direction: column;\n  align-items: flex-start;\n  gap: 4px;\n  line-height: 1;\n}\n\n.data-container {\n  display: flex;\n  flex-direction: column;\n  align-items: flex-start;\n  gap: 4px;\n  line-height: 1;\n}\n\n.data-content-container {\n  display: block;\n  width: 100%;\n  min-height: 100px;\n  height: 100px;\n  border: 1px solid #ccc;\n  border-radius: 4px;\n  padding: 8px;\n  overflow-y: auto;\n  font-family: inherit;\n  font-size: inherit;\n  background-color: #f9f9f9;\n  white-space: pre-wrap;\n  word-wrap: break-word;\n  color: #333;\n}\n\n.data-content {\n  opacity: 0.6;\n}\n\n.fee-container {\n  display: flex;\n  flex-direction: column;\n  align-items: flex-start;\n  gap: 4px;\n  line-height: 1;\n}\n\n.sign-button-container {\n  display: flex;\n  flex-direction: column;\n}\n\n.sign-back-button {\n  display: inline-block;\n  padding: 8px 12px;\n  background-color: transparent;\n  color: #1a56db;\n  border: none;\n  border-radius: 4px;\n  cursor: pointer;\n  text-decoration: none;\n  font-size: 16px;\n\n  &:hover {\n    text-decoration: underline;\n    color: #0033a0;\n  }\n\n  &:active {\n    color: #001f70;\n  }\n\n  &:disabled {\n    color: #a1a1a1;\n    cursor: not-allowed;\n    text-decoration: none;\n    opacity: 0.6;\n  }\n}\n\n.sign-button {\n  display: block;\n  width: 200px;\n  margin: 0 auto;\n  padding: 12px;\n  background-color: #1a56db;\n  color: white;\n  border: none;\n  border-radius: 8px;\n  cursor: pointer;\n\n  &:disabled {\n    background-color: #a1a1a1;\n    color: #e0e0e0;\n    cursor: not-allowed;\n    opacity: 0.6;\n    box-shadow: none;\n    transform: none;\n  }\n}\n\n.highlight {\n  opacity: 1;\n}\n";

var __rest = (undefined && undefined.__rest) || function (s, e) {
    var t = {};
    for (var p in s)
        if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
            t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
const SignTransaction = /*@__PURE__*/ proxyCustomElement(class SignTransaction extends H {
    constructor() {
        super();
        this.__registerHost();
    }
    getSignButtonProps() {
        const { needsSigning } = state.commonData;
        if (needsSigning) {
            return {
                'signText': 'Sign',
                'disabled': state.isWaitingForSignature,
                'data-testid': DataTestIdsEnum.signTransactionBtn,
                'onClick': state.onConfirm,
            };
        }
        return {
            'signText': 'Next',
            'disabled': false,
            'data-testid': DataTestIdsEnum.signNextTransactionBtn,
            'onClick': state.onConfirm,
        };
    }
    getBackButtonProps() {
        const { transactionsCount, currentIndex } = state.commonData;
        const isMultipleTransactions = transactionsCount > 1;
        if (!isMultipleTransactions) {
            return {};
        }
        if (currentIndex === 0) {
            return {
                'data-testid': DataTestIdsEnum.signCancelBtn,
                'backButtonText': 'Cancel',
                'onClick': state.onCancel,
            };
        }
        return {
            'data-testid': DataTestIdsEnum.signBackBtn,
            'backButtonText': 'Back',
            'onClick': state.onBack,
            'disabled': state.isWaitingForSignature,
        };
    }
    getHighlightedData() {
        const { data, highlight } = state.commonData;
        if (!highlight || !data) {
            return data;
        }
        const parts = data.split(highlight);
        return (h("span", null, parts.map((part, index) => (h("span", null, h("span", { class: "data-content" }, part), index < parts.length - 1 && h("span", { class: "highlight" }, highlight))))));
    }
    render() {
        const { receiver, scCall } = state.commonData;
        const _a = this.getSignButtonProps(), { signText } = _a, signButtonProps = __rest(_a, ["signText"]);
        const _b = this.getBackButtonProps(), { backButtonText } = _b, backButtonProps = __rest(_b, ["backButtonText"]);
        const highlightedData = this.getHighlightedData();
        return (h("div", { key: '0a1624c4494171725e7c790275ded0711475c48a', class: "transaction-container" }, this.header, h("div", { key: '6c007f6a9bcf9a9f794bb1d5afc7282d32f57d22', class: "receiver-container" }, h("p", { key: '07939c79bba48453d19b560cac2bc2660613234a' }, "To"), h("p", { key: '8264fd0565f6bbe226887990bcd794131abc9f84' }, formatAddress(receiver, 40))), h("mvx-transaction-fee-component", { key: '9b31561bee96d1ba0ac959b50fd9e0f171c08c58' }), scCall && (h("div", { key: 'e7699b5bad4b7b590d3382792c46d2e76a36923f', class: "data-container" }, h("p", { key: '61b71377a8acfa69d3e0fe578e6e34c16d0cce83' }, "Smart Contract Call"), h("div", { key: '5f6eda17fa42f0c45b0641b31bc2fe4eea6cdc34', class: "data-content-container" }, scCall))), h("div", { key: 'd4c0d74612b6a790f5c2bc0f3a1b8cf948a0b449', class: "data-container" }, h("p", { key: '7a43db58d1bf9aca66104eb99cf96e9a9bb2481e' }, "Data"), h("div", { key: '21d0a76ef527fb9b7f4d20d19fd81a3246bd43c4', class: "data-content-container" }, highlightedData)), h("div", { key: '43f582b8248cb7cbf349a2f044d74b488ed4ae69', class: "sign-button-container" }, h("button", Object.assign({ key: '92624f8b52a3b3fffba78a425354d75d47a703ce', class: "sign-button" }, signButtonProps), signText), backButtonText && (h("button", Object.assign({ key: '54665911aee4db0d6c59e7887167fc106981b4d8', class: "sign-back-button" }, backButtonProps), backButtonText)))));
    }
    static get style() { return signTransactionComponentCss; }
}, [0, "mvx-sign-transaction-component", {
        "header": [16]
    }]);
function defineCustomElement() {
    if (typeof customElements === "undefined") {
        return;
    }
    const components = ["mvx-sign-transaction-component", "mvx-transaction-fee-component"];
    components.forEach(tagName => { switch (tagName) {
        case "mvx-sign-transaction-component":
            if (!customElements.get(tagName)) {
                customElements.define(tagName, SignTransaction);
            }
            break;
        case "mvx-transaction-fee-component":
            if (!customElements.get(tagName)) {
                defineCustomElement$1();
            }
            break;
    } });
}

export { SignTransaction as S, defineCustomElement as d };
//# sourceMappingURL=p-nIZyqk92.js.map

//# sourceMappingURL=p-nIZyqk92.js.map